Learn R Programming

paws.database (version 0.2.0)

dax_create_parameter_group: Creates a new parameter group

Description

Creates a new parameter group. A parameter group is a collection of parameters that you apply to all of the nodes in a DAX cluster.

See https://paws-r.github.io/docs/dax/create_parameter_group.html for full documentation.

Usage

dax_create_parameter_group(ParameterGroupName, Description = NULL)

Arguments

ParameterGroupName

[required] The name of the parameter group to apply to all of the clusters in this replication group.

Description

A description of the parameter group.