Removes one or more nodes from a DAX cluster.
See https://paws-r.github.io/docs/dax/decrease_replication_factor.html for full documentation.
dax_decrease_replication_factor(
ClusterName,
NewReplicationFactor,
AvailabilityZones = NULL,
NodeIdsToRemove = NULL
)[required] The name of the DAX cluster from which you want to remove nodes.
[required] The new number of nodes for the DAX cluster.
The Availability Zone(s) from which to remove nodes.
The unique identifiers of the nodes to be removed from the cluster.