Learn R Programming

paws.database (version 0.2.0)

dax_delete_cluster: Deletes a previously provisioned DAX cluster

Description

Deletes a previously provisioned DAX cluster. DeleteCluster deletes all associated nodes, node endpoints and the DAX cluster itself. When you receive a successful response from this action, DAX immediately begins deleting the cluster; you cannot cancel or revert this action.

See https://paws-r.github.io/docs/dax/delete_cluster.html for full documentation.

Usage

dax_delete_cluster(ClusterName)

Arguments

ClusterName

[required] The name of the cluster to be deleted.