Learn R Programming

paws.database (version 0.1.6)

dax_list_tags: List all of the tags for a DAX cluster

Description

List all of the tags for a DAX cluster. You can call ListTags up to 10 times per second, per account.

Usage

dax_list_tags(ResourceName, NextToken)

Arguments

ResourceName

[required] The name of the DAX resource to which the tags belong.

NextToken

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token.

Request syntax

svc$list_tags(
  ResourceName = "string",
  NextToken = "string"
)