Learn R Programming

paws.database (version 0.2.0)

dax_reboot_node: Reboots a single node of a DAX cluster

Description

Reboots a single node of a DAX cluster. The reboot action takes place as soon as possible. During the reboot, the node status is set to REBOOTING.

See https://paws-r.github.io/docs/dax/reboot_node.html for full documentation.

Usage

dax_reboot_node(ClusterName, NodeId)

Arguments

ClusterName

[required] The name of the DAX cluster containing the node to be rebooted.

NodeId

[required] The system-assigned ID of the node to be rebooted.