Adds metadata tags to an Amazon DocumentDB resource. You can use these
tags with cost allocation reporting to track costs that are associated
with Amazon DocumentDB resources. or in a Condition statement in an
AWS Identity and Access Management (IAM) policy for Amazon DocumentDB.
docdb_add_tags_to_resource(ResourceName, Tags)[required] The Amazon DocumentDB resource that the tags are added to. This value is an Amazon Resource Name (ARN).
[required] The tags to be assigned to the Amazon DocumentDB resource.
svc$add_tags_to_resource(
ResourceName = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)