Creates a new cluster parameter group.
See https://paws-r.github.io/docs/docdb/create_db_cluster_parameter_group.html for full documentation.
docdb_create_db_cluster_parameter_group(
DBClusterParameterGroupName,
DBParameterGroupFamily,
Description,
Tags = NULL
)[required] The name of the cluster parameter group.
Constraints:
Must not match the name of an existing DBClusterParameterGroup.
This value is stored as a lowercase string.
[required] The cluster parameter group family name.
[required] The description for the cluster parameter group.
The tags to be assigned to the cluster parameter group.