Deletes a cluster snapshot. If the snapshot is being copied, the copy operation is terminated.
See https://paws-r.github.io/docs/docdb/delete_db_cluster_snapshot.html for full documentation.
docdb_delete_db_cluster_snapshot(DBClusterSnapshotIdentifier)[required] The identifier of the cluster snapshot to delete.
Constraints: Must be the name of an existing cluster snapshot in the
available state.