powered by
Deletes a global cluster. The primary and secondary clusters must already be detached or deleted before attempting to delete a global cluster.
See https://paws-r.github.io/docs/docdb/delete_global_cluster.html for full documentation.
docdb_delete_global_cluster(GlobalClusterIdentifier)
[required] The cluster identifier of the global cluster being deleted.