Returns a list of cluster snapshot attribute names and values for a manual DB cluster snapshot.
See https://paws-r.github.io/docs/docdb/describe_db_cluster_snapshot_attributes.html for full documentation.
docdb_describe_db_cluster_snapshot_attributes(DBClusterSnapshotIdentifier)[required] The identifier for the cluster snapshot to describe the attributes for.