Modify a setting for an Amazon DocumentDB global cluster. You can change one or more configuration parameters (for example: deletion protection), or the global cluster identifier by specifying these parameters and the new values in the request.
See https://paws-r.github.io/docs/docdb/modify_global_cluster.html for full documentation.
docdb_modify_global_cluster(
GlobalClusterIdentifier,
NewGlobalClusterIdentifier = NULL,
DeletionProtection = NULL
)[required] The identifier for the global cluster being modified. This parameter isn't case-sensitive.
Constraints:
Must match the identifier of an existing global cluster.
The new identifier for a global cluster when you modify a global cluster. This value is stored as a lowercase string.
Must contain from 1 to 63 letters, numbers, or hyphens
The first character must be a letter
Can't end with a hyphen or contain two consecutive hyphens
Example: my-cluster2
Indicates if the global cluster has deletion protection enabled. The global cluster can't be deleted when deletion protection is enabled.