Learn R Programming

paws.database (version 0.2.0)

docdb_remove_from_global_cluster: Detaches an Amazon DocumentDB secondary cluster from a global cluster

Description

Detaches an Amazon DocumentDB secondary cluster from a global cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary in a different region.

See https://paws-r.github.io/docs/docdb/remove_from_global_cluster.html for full documentation.

Usage

docdb_remove_from_global_cluster(GlobalClusterIdentifier, DbClusterIdentifier)

Arguments

GlobalClusterIdentifier

[required] The cluster identifier to detach from the Amazon DocumentDB global cluster.

DbClusterIdentifier

[required] The Amazon Resource Name (ARN) identifying the cluster that was detached from the Amazon DocumentDB global cluster.