Learn R Programming

paws.database (version 0.2.0)

docdb_remove_source_identifier_from_subscription: Removes a source identifier from an existing Amazon DocumentDB event notification subscription

Description

Removes a source identifier from an existing Amazon DocumentDB event notification subscription.

See https://paws-r.github.io/docs/docdb/remove_source_identifier_from_subscription.html for full documentation.

Usage

docdb_remove_source_identifier_from_subscription(
  SubscriptionName,
  SourceIdentifier
)

Arguments

SubscriptionName

[required] The name of the Amazon DocumentDB event notification subscription that you want to remove a source identifier from.

SourceIdentifier

[required] The source identifier to be removed from the subscription, such as the instance identifier for an instance, or the name of a security group.