Learn R Programming

paws.database (version 0.2.0)

docdb_reset_db_cluster_parameter_group: Modifies the parameters of a cluster parameter group to the default value

Description

Modifies the parameters of a cluster parameter group to the default value. To reset specific parameters, submit a list of the following: ParameterName and ApplyMethod. To reset the entire cluster parameter group, specify the DBClusterParameterGroupName and ResetAllParameters parameters.

See https://paws-r.github.io/docs/docdb/reset_db_cluster_parameter_group.html for full documentation.

Usage

docdb_reset_db_cluster_parameter_group(
  DBClusterParameterGroupName,
  ResetAllParameters = NULL,
  Parameters = NULL
)

Arguments

DBClusterParameterGroupName

[required] The name of the cluster parameter group to reset.

ResetAllParameters

A value that is set to true to reset all parameters in the cluster parameter group to their default values, and false otherwise. You can't use this parameter if there is a list of parameter names specified for the Parameters parameter.

Parameters

A list of parameter names in the cluster parameter group to reset to the default values. You can't use this parameter if the ResetAllParameters parameter is set to true.