Restarts the stopped cluster that is specified by DBClusterIdentifier. For more information, see Stopping and Starting an Amazon DocumentDB Cluster.
See https://paws-r.github.io/docs/docdb/start_db_cluster.html for full documentation.
docdb_start_db_cluster(DBClusterIdentifier)[required] The identifier of the cluster to restart. Example:
docdb-2019-05-28-15-24-52