View source: R/docdbelastic_operations.R
| docdbelastic_apply_pending_maintenance_action | R Documentation |
The type of pending maintenance action to be applied to the resource.
See https://www.paws-r-sdk.com/docs/docdbelastic_apply_pending_maintenance_action/ for full documentation.
docdbelastic_apply_pending_maintenance_action(
applyAction,
applyOn = NULL,
optInType,
resourceArn
)
applyAction |
[required] The pending maintenance action to apply to the resource. Valid actions are:
|
applyOn |
A specific date to apply the pending maintenance action. Required if opt-in-type is |
optInType |
[required] A value that specifies the type of opt-in request, or undoes an opt-in request. An opt-in request of type |
resourceArn |
[required] The Amazon DocumentDB Amazon Resource Name (ARN) of the resource to which the pending maintenance action applies. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.