dynamodb_batch_execute_statement: This operation allows you to perform batch reads or writes on...

View source: R/dynamodb_operations.R

dynamodb_batch_execute_statementR Documentation

This operation allows you to perform batch reads or writes on data stored in DynamoDB, using PartiQL

Description

This operation allows you to perform batch reads or writes on data stored in DynamoDB, using PartiQL. Each read statement in a batch_execute_statement must specify an equality condition on all key attributes. This enforces that each SELECT statement in a batch returns at most a single item. For more information, see Running batch operations with PartiQL for DynamoDB .

See https://www.paws-r-sdk.com/docs/dynamodb_batch_execute_statement/ for full documentation.

Usage

dynamodb_batch_execute_statement(Statements, ReturnConsumedCapacity = NULL)

Arguments

Statements

[required] The list of PartiQL statements representing the batch to run.

ReturnConsumedCapacity

Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:

  • INDEXES - The response includes the aggregate ConsumedCapacity for the operation, together with ConsumedCapacity for each table and secondary index that was accessed.

    Note that some operations, such as get_item and batch_get_item, do not access any indexes at all. In these cases, specifying INDEXES will only return ConsumedCapacity information for table(s).

  • TOTAL - The response includes only the aggregate ConsumedCapacity for the operation.

  • NONE - No ConsumedCapacity details are included in the response.


paws.database documentation built on June 1, 2026, 5:08 p.m.