View source: R/dynamodb_operations.R
| dynamodb_batch_get_item | R Documentation |
The batch_get_item operation returns the attributes of one or more items from one or more tables. You identify requested items by primary key.
See https://www.paws-r-sdk.com/docs/dynamodb_batch_get_item/ for full documentation.
dynamodb_batch_get_item(RequestItems, ReturnConsumedCapacity = NULL)
RequestItems |
[required] A map of one or more table names or table ARNs and, for each table, a map that describes one or more items to retrieve from that table. Each table name or ARN can be used only once per Each element in the map of items to retrieve consists of the following:
|
ReturnConsumedCapacity |
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.