dynamodb_create_global_table: Creates a global table from an existing table

View source: R/dynamodb_operations.R

dynamodb_create_global_tableR Documentation

Creates a global table from an existing table

Description

Creates a global table from an existing table. A global table creates a replication relationship between two or more DynamoDB tables with the same table name in the provided Regions.

See https://www.paws-r-sdk.com/docs/dynamodb_create_global_table/ for full documentation.

Usage

dynamodb_create_global_table(GlobalTableName, ReplicationGroup)

Arguments

GlobalTableName

[required] The global table name.

ReplicationGroup

[required] The Regions where the global table needs to be created.


paws.database documentation built on June 1, 2026, 5:08 p.m.