Learn R Programming

paws.database (version 0.2.0)

dynamodb_describe_contributor_insights: Returns information about contributor insights, for a given table or global secondary index

Description

Returns information about contributor insights, for a given table or global secondary index.

See https://paws-r.github.io/docs/dynamodb/describe_contributor_insights.html for full documentation.

Usage

dynamodb_describe_contributor_insights(TableName, IndexName = NULL)

Arguments

TableName

[required] The name of the table to describe.

IndexName

The name of the global secondary index to describe, if applicable.