Learn R Programming

paws.database (version 0.2.0)

dynamodb_describe_limits: Returns the current provisioned-capacity quotas for your Amazon Web Services account in a Region, both for the Region as a whole and for any one DynamoDB table that you create there

Description

Returns the current provisioned-capacity quotas for your Amazon Web Services account in a Region, both for the Region as a whole and for any one DynamoDB table that you create there.

See https://paws-r.github.io/docs/dynamodb/describe_limits.html for full documentation.

Usage

dynamodb_describe_limits()

Arguments