Returns information about the table, including the current status of the table, when it was created, the primary key schema, and any indexes on the table.
See https://paws-r.github.io/docs/dynamodb/describe_table.html for full documentation.
dynamodb_describe_table(TableName)[required] The name of the table to describe.