Learn R Programming

paws.database (version 0.2.0)

dynamodb_describe_table_replica_auto_scaling: Describes auto scaling settings across replicas of the global table at once

Description

Describes auto scaling settings across replicas of the global table at once.

See https://paws-r.github.io/docs/dynamodb/describe_table_replica_auto_scaling.html for full documentation.

Usage

dynamodb_describe_table_replica_auto_scaling(TableName)

Arguments

TableName

[required] The name of the table.