Starts table data replication to the specified Kinesis data stream at a timestamp chosen during the enable workflow. If this operation doesn't return results immediately, use DescribeKinesisStreamingDestination to check if streaming to the Kinesis data stream is ACTIVE.
See https://paws-r.github.io/docs/dynamodb/enable_kinesis_streaming_destination.html for full documentation.
dynamodb_enable_kinesis_streaming_destination(TableName, StreamArn)[required] The name of the DynamoDB table.
[required] The ARN for a Kinesis data stream.