View source: R/dynamodb_operations.R
| dynamodb_execute_statement | R Documentation |
This operation allows you to perform reads and singleton writes on data stored in DynamoDB, using PartiQL.
See https://www.paws-r-sdk.com/docs/dynamodb_execute_statement/ for full documentation.
dynamodb_execute_statement(
Statement,
Parameters = NULL,
ConsistentRead = NULL,
NextToken = NULL,
ReturnConsumedCapacity = NULL,
Limit = NULL,
ReturnValuesOnConditionCheckFailure = NULL
)
Statement |
[required] The PartiQL statement representing the operation to run. |
Parameters |
The parameters for the PartiQL statement, if any. |
ConsistentRead |
The consistency of a read operation. If set to |
NextToken |
Set this value to get remaining results, if |
ReturnConsumedCapacity |
Determines the level of detail about either provisioned or on-demand throughput consumption that is returned in the response:
|
Limit |
The maximum number of items to evaluate (not necessarily the number of matching items). If DynamoDB processes the number of items up to the limit while processing the results, it stops the operation and returns the matching values up to that point, along with a key in |
ReturnValuesOnConditionCheckFailure |
An optional parameter that returns the item attributes for an There is no additional cost associated with requesting a return value aside from the small network and processing overhead of receiving a larger response. No read capacity units are consumed. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.