Returns a list of ContributorInsightsSummary for a table and all its global secondary indexes.
See https://paws-r.github.io/docs/dynamodb/list_contributor_insights.html for full documentation.
dynamodb_list_contributor_insights(
TableName = NULL,
NextToken = NULL,
MaxResults = NULL
)The name of the table.
A token to for the desired page, if there is one.
Maximum number of results to return per page.