Returns an array of table names associated with the current account and endpoint. The output from list_tables is paginated, with each page returning a maximum of 100 table names.
See https://paws-r.github.io/docs/dynamodb/list_tables.html for full documentation.
dynamodb_list_tables(ExclusiveStartTableName = NULL, Limit = NULL)The first table name that this operation will evaluate. Use the value
that was returned for LastEvaluatedTableName in a previous operation,
so that you can obtain the next page of results.
A maximum number of table names to return. If this parameter is not specified, the limit is 100.