Learn R Programming

paws.database (version 0.1.6)

dynamodb_list_tags_of_resource: List all tags on an Amazon DynamoDB resource

Description

List all tags on an Amazon DynamoDB resource. You can call ListTagsOfResource up to 10 times per second, per account.

Usage

dynamodb_list_tags_of_resource(ResourceArn, NextToken)

Arguments

ResourceArn

[required] The Amazon DynamoDB resource with tags to be listed. This value is an Amazon Resource Name (ARN).

NextToken

An optional string that, if supplied, must be copied from the output of a previous call to ListTagOfResource. When provided in this manner, this API fetches the next page of results.

Request syntax

svc$list_tags_of_resource(
  ResourceArn = "string",
  NextToken = "string"
)

Details

For an overview on tagging DynamoDB resources, see Tagging for DynamoDB in the Amazon DynamoDB Developer Guide.