Learn R Programming

paws.database (version 0.2.0)

dynamodb_transact_get_items: TransactGetItems is a synchronous operation that atomically retrieves multiple items from one or more tables (but not from indexes) in a single account and Region

Description

transact_get_items is a synchronous operation that atomically retrieves multiple items from one or more tables (but not from indexes) in a single account and Region. A transact_get_items call can contain up to 25 TransactGetItem objects, each of which contains a Get structure that specifies an item to retrieve from a table in the account and Region. A call to transact_get_items cannot retrieve items from tables in more than one Amazon Web Services account or Region. The aggregate size of the items in the transaction cannot exceed 4 MB.

See https://paws-r.github.io/docs/dynamodb/transact_get_items.html for full documentation.

Usage

dynamodb_transact_get_items(TransactItems, ReturnConsumedCapacity = NULL)

Arguments

TransactItems

[required] An ordered array of up to 25 TransactGetItem objects, each of which contains a Get structure.

ReturnConsumedCapacity

A value of TOTAL causes consumed capacity information to be returned, and a value of NONE prevents that information from being returned. No other value is valid.