Removes the association of tags from an Amazon DynamoDB resource. You can call untag_resource up to five times per second, per account.
See https://paws-r.github.io/docs/dynamodb/untag_resource.html for full documentation.
dynamodb_untag_resource(ResourceArn, TagKeys)[required] The DynamoDB resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).
[required] A list of tag keys. Existing tags of the resource whose keys are members of this list will be removed from the DynamoDB resource.