Adds up to 50 cost allocation tags to the named resource. A cost allocation tag is a key-value pair where the key and value are case-sensitive. You can use cost allocation tags to categorize and track your AWS costs.
elasticache_add_tags_to_resource(ResourceName, Tags)[required] The Amazon Resource Name (ARN) of the resource to which the tags are to
be added, for example
arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or
arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot.
ElastiCache resources are cluster and snapshot.
For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.
[required] A list of cost allocation tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value.
svc$add_tags_to_resource(
ResourceName = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)
When you apply tags to your ElastiCache resources, AWS generates a cost allocation report as a comma-separated value (CSV) file with your usage and costs aggregated by your tags. You can apply tags that represent business categories (such as cost centers, application names, or owners) to organize your costs across multiple services. For more information, see Using Cost Allocation Tags in Amazon ElastiCache in the ElastiCache User Guide.