Creates a new cache security group. Use a cache security group to control access to one or more clusters.
See https://paws-r.github.io/docs/elasticache/create_cache_security_group.html for full documentation.
elasticache_create_cache_security_group(
CacheSecurityGroupName,
Description,
Tags = NULL
)[required] A name for the cache security group. This value is stored as a lowercase string.
Constraints: Must contain no more than 255 alphanumeric characters. Cannot be the word "Default".
Example: mysecuritygroup
[required] A description for the cache security group.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.