Creates a new cache subnet group.
See https://paws-r.github.io/docs/elasticache/create_cache_subnet_group.html for full documentation.
elasticache_create_cache_subnet_group(
CacheSubnetGroupName,
CacheSubnetGroupDescription,
SubnetIds,
Tags = NULL
)[required] A name for the cache subnet group. This value is stored as a lowercase string.
Constraints: Must contain no more than 255 alphanumeric characters or hyphens.
Example: mysubnetgroup
[required] A description for the cache subnet group.
[required] A list of VPC subnet IDs for the cache subnet group.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.