elasticache_create_user: For Valkey engine version 7

View source: R/elasticache_operations.R

elasticache_create_userR Documentation

For Valkey engine version 7

Description

For Valkey engine version 7.2 onwards and Redis OSS 6.0 to 7.1: Creates a user. For more information, see Using Role Based Access Control (RBAC).

See https://www.paws-r-sdk.com/docs/elasticache_create_user/ for full documentation.

Usage

elasticache_create_user(
  UserId,
  UserName,
  Engine,
  Passwords = NULL,
  AccessString,
  NoPasswordRequired = NULL,
  Tags = NULL,
  AuthenticationMode = NULL
)

Arguments

UserId

[required] The ID of the user. This value is stored as a lowercase string.

UserName

[required] The username of the user.

Engine

[required] The options are valkey or redis.

Passwords

Passwords used for this user. You can create up to two passwords for each user.

AccessString

[required] Access permissions string used for this user.

NoPasswordRequired

Indicates a password is not required for this user.

Tags

A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.

AuthenticationMode

Specifies how to authenticate the user.


paws.database documentation built on June 1, 2026, 5:08 p.m.