Learn R Programming

paws.database (version 0.2.0)

elasticache_delete_cache_cluster: Deletes a previously provisioned cluster

Description

Deletes a previously provisioned cluster. delete_cache_cluster deletes all associated cache nodes, node endpoints and the cluster itself. When you receive a successful response from this operation, Amazon ElastiCache immediately begins deleting the cluster; you cannot cancel or revert this operation.

See https://paws-r.github.io/docs/elasticache/delete_cache_cluster.html for full documentation.

Usage

elasticache_delete_cache_cluster(
  CacheClusterId,
  FinalSnapshotIdentifier = NULL
)

Arguments

CacheClusterId

[required] The cluster identifier for the cluster to be deleted. This parameter is not case sensitive.

FinalSnapshotIdentifier

The user-supplied name of a final cluster snapshot. This is the unique name that identifies the snapshot. ElastiCache creates the snapshot, and then deletes the cluster immediately afterward.