For Redis engine version 6.0 onwards: Deletes a user. The user will be removed from all user groups and in turn removed from all replication groups. For more information, see Using Role Based Access Control (RBAC).
See https://paws-r.github.io/docs/elasticache/delete_user.html for full documentation.