Remove a secondary cluster from the Global datastore using the Global datastore name. The secondary cluster will no longer receive updates from the primary cluster, but will remain as a standalone cluster in that Amazon region.
See https://paws-r.github.io/docs/elasticache/disassociate_global_replication_group.html for full documentation.
elasticache_disassociate_global_replication_group(
GlobalReplicationGroupId,
ReplicationGroupId,
ReplicationGroupRegion
)[required] The name of the Global datastore
[required] The name of the secondary cluster you wish to remove from the Global datastore
[required] The Amazon region of secondary cluster you wish to remove from the Global datastore