View source: R/elasticache_operations.R
| elasticache_export_serverless_cache_snapshot | R Documentation |
Provides the functionality to export the serverless cache snapshot data to Amazon S3. Available for Valkey and Redis OSS only.
See https://www.paws-r-sdk.com/docs/elasticache_export_serverless_cache_snapshot/ for full documentation.
elasticache_export_serverless_cache_snapshot(
ServerlessCacheSnapshotName,
S3BucketName
)
ServerlessCacheSnapshotName |
[required] The identifier of the serverless cache snapshot to be exported to S3. Available for Valkey and Redis OSS only. |
S3BucketName |
[required] Name of the Amazon S3 bucket to export the snapshot to. The Amazon S3 bucket must also be in same region as the snapshot. Available for Valkey and Redis OSS only. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.