Learn R Programming

paws.database (version 0.2.0)

elasticache_failover_global_replication_group: Used to failover the primary region to a selected secondary region

Description

Used to failover the primary region to a selected secondary region. The selected secondary region will become primary, and all other clusters will become secondary.

See https://paws-r.github.io/docs/elasticache/failover_global_replication_group.html for full documentation.

Usage

elasticache_failover_global_replication_group(
  GlobalReplicationGroupId,
  PrimaryRegion,
  PrimaryReplicationGroupId
)

Arguments

GlobalReplicationGroupId

[required] The name of the Global datastore

PrimaryRegion

[required] The Amazon region of the primary cluster of the Global datastore

PrimaryReplicationGroupId

[required] The name of the primary replication group