Learn R Programming

paws.database (version 0.1.6)

elasticache_list_allowed_node_type_modifications: Lists all available node types that you can scale your Redis cluster's or replication group's current node type

Description

Lists all available node types that you can scale your Redis cluster\'s or replication group\'s current node type.

Usage

elasticache_list_allowed_node_type_modifications(CacheClusterId,
  ReplicationGroupId)

Arguments

CacheClusterId

The name of the cluster you want to scale up to a larger node instanced type. ElastiCache uses the cluster id to identify the current node type of this cluster and from that to create a list of node types you can scale up to.

You must provide a value for either the CacheClusterId or the ReplicationGroupId.

ReplicationGroupId

The name of the replication group want to scale up to a larger node type. ElastiCache uses the replication group id to identify the current node type being used by this replication group, and from that to create a list of node types you can scale up to.

You must provide a value for either the CacheClusterId or the ReplicationGroupId.

Request syntax

svc$list_allowed_node_type_modifications(
  CacheClusterId = "string",
  ReplicationGroupId = "string"
)

Details

When you use the ModifyCacheCluster or ModifyReplicationGroup operations to scale your cluster or replication group, the value of the CacheNodeType parameter must be one of the node types returned by this operation.