Learn R Programming

paws.database (version 0.1.6)

elasticache_list_tags_for_resource: Lists all cost allocation tags currently on the named resource

Description

Lists all cost allocation tags currently on the named resource. A cost allocation tag is a key-value pair where the key is case-sensitive and the value is optional. You can use cost allocation tags to categorize and track your AWS costs.

Usage

elasticache_list_tags_for_resource(ResourceName)

Arguments

ResourceName

[required] The Amazon Resource Name (ARN) of the resource for which you want the list of tags, for example arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot.

For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.

Request syntax

svc$list_tags_for_resource(
  ResourceName = "string"
)

Details

If the cluster is not in the available state, ListTagsForResource returns an error.

You can have a maximum of 50 cost allocation tags on an ElastiCache resource. For more information, see Monitoring Costs with Tags.