elasticache_modify_user_group: Changes the list of users that belong to the user group

View source: R/elasticache_operations.R

elasticache_modify_user_groupR Documentation

Changes the list of users that belong to the user group

Description

Changes the list of users that belong to the user group.

See https://www.paws-r-sdk.com/docs/elasticache_modify_user_group/ for full documentation.

Usage

elasticache_modify_user_group(
  UserGroupId,
  UserIdsToAdd = NULL,
  UserIdsToRemove = NULL,
  Engine = NULL
)

Arguments

UserGroupId

[required] The ID of the user group.

UserIdsToAdd

The list of user IDs to add to the user group.

UserIdsToRemove

The list of user IDs to remove from the user group.

Engine

Modifies the engine listed in a user group. The options are valkey or redis.


paws.database documentation built on June 1, 2026, 5:08 p.m.