Learn R Programming

paws.database (version 0.2.0)

elasticache_rebalance_slots_in_global_replication_group: Redistribute slots to ensure uniform distribution across existing shards in the cluster

Description

Redistribute slots to ensure uniform distribution across existing shards in the cluster.

See https://paws-r.github.io/docs/elasticache/rebalance_slots_in_global_replication_group.html for full documentation.

Usage

elasticache_rebalance_slots_in_global_replication_group(
  GlobalReplicationGroupId,
  ApplyImmediately
)

Arguments

GlobalReplicationGroupId

[required] The name of the Global datastore

ApplyImmediately

[required] If True, redistribution is applied immediately.