Learn R Programming

paws.database (version 0.2.0)

elasticache_reboot_cache_cluster: Reboots some, or all, of the cache nodes within a provisioned cluster

Description

Reboots some, or all, of the cache nodes within a provisioned cluster. This operation applies any modified cache parameter groups to the cluster. The reboot operation takes place as soon as possible, and results in a momentary outage to the cluster. During the reboot, the cluster status is set to REBOOTING.

See https://paws-r.github.io/docs/elasticache/reboot_cache_cluster.html for full documentation.

Usage

elasticache_reboot_cache_cluster(CacheClusterId, CacheNodeIdsToReboot)

Arguments

CacheClusterId

[required] The cluster identifier. This parameter is stored as a lowercase string.

CacheNodeIdsToReboot

[required] A list of cache node IDs to reboot. A node ID is a numeric identifier (0001, 0002, etc.). To reboot an entire cluster, specify all of the cache node IDs.