Removes the tags identified by the TagKeys list from the named resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your ElastiCache resources, with the exception of global replication group. When you add or remove tags on replication groups, those actions will be replicated to all nodes in the replication group. For more information, see Resource-level permissions.
See https://www.paws-r-sdk.com/docs/elasticache_remove_tags_from_resource/ for full documentation.
elasticache_remove_tags_from_resource(ResourceName, TagKeys)[required] The Amazon Resource Name (ARN) of the resource from which you want the
tags removed, for example
arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or
arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot.
For more information about ARNs, see Amazon Resource Names (ARNs) and Amazon Service Namespaces.
[required] A list of TagKeys identifying the tags you want removed from the named
resource.