Learn R Programming

paws.database (version 0.2.0)

elasticache_revoke_cache_security_group_ingress: Revokes ingress from a cache security group

Description

Revokes ingress from a cache security group. Use this operation to disallow access from an Amazon EC2 security group that had been previously authorized.

See https://paws-r.github.io/docs/elasticache/revoke_cache_security_group_ingress.html for full documentation.

Usage

elasticache_revoke_cache_security_group_ingress(
  CacheSecurityGroupName,
  EC2SecurityGroupName,
  EC2SecurityGroupOwnerId
)

Arguments

CacheSecurityGroupName

[required] The name of the cache security group to revoke ingress from.

EC2SecurityGroupName

[required] The name of the Amazon EC2 security group to revoke access from.

EC2SecurityGroupOwnerId

[required] The Amazon account number of the Amazon EC2 security group owner. Note that this is not the same thing as an Amazon access key ID - you must provide a valid Amazon account number for this parameter.