elasticache_start_migration: Start the migration of data

View source: R/elasticache_operations.R

elasticache_start_migrationR Documentation

Start the migration of data

Description

Start the migration of data.

See https://www.paws-r-sdk.com/docs/elasticache_start_migration/ for full documentation.

Usage

elasticache_start_migration(ReplicationGroupId, CustomerNodeEndpointList)

Arguments

ReplicationGroupId

[required] The ID of the replication group to which data should be migrated.

CustomerNodeEndpointList

[required] List of endpoints from which data should be migrated. For Valkey or Redis OSS (cluster mode disabled), the list should have only one element.


paws.database documentation built on June 1, 2026, 5:08 p.m.