Learn R Programming

paws.database (version 0.2.0)

keyspaces_create_keyspace: The CreateKeyspace operation adds a new keyspace to your account

Description

The create_keyspace operation adds a new keyspace to your account. In an Amazon Web Services account, keyspace names must be unique within each Region.

See https://paws-r.github.io/docs/keyspaces/create_keyspace.html for full documentation.

Usage

keyspaces_create_keyspace(keyspaceName, tags = NULL)

Arguments

keyspaceName

[required] The name of the keyspace to be created.

tags

A list of key-value pair tags to be attached to the keyspace.

For more information, see Adding tags and labels to Amazon Keyspaces resources in the Amazon Keyspaces Developer Guide.