keyspaces_delete_type: The DeleteType operation deletes a user-defined type (UDT)

View source: R/keyspaces_operations.R

keyspaces_delete_typeR Documentation

The DeleteType operation deletes a user-defined type (UDT)

Description

The delete_type operation deletes a user-defined type (UDT). You can only delete a type that is not used in a table or another UDT.

See https://www.paws-r-sdk.com/docs/keyspaces_delete_type/ for full documentation.

Usage

keyspaces_delete_type(keyspaceName, typeName)

Arguments

keyspaceName

[required] The name of the keyspace of the to be deleted type.

typeName

[required] The name of the type to be deleted.


paws.database documentation built on June 1, 2026, 5:08 p.m.