View source: R/keyspaces_operations.R
| keyspaces_get_keyspace | R Documentation |
Returns the name of the specified keyspace, the Amazon Resource Name (ARN), the replication strategy, the Amazon Web Services Regions of a multi-Region keyspace, and the status of newly added Regions after an update_keyspace operation.
See https://www.paws-r-sdk.com/docs/keyspaces_get_keyspace/ for full documentation.
keyspaces_get_keyspace(keyspaceName)
keyspaceName |
[required] The name of the keyspace. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.