Returns a list of tables for a specified keyspace.
See https://paws-r.github.io/docs/keyspaces/list_tables.html for full documentation.
keyspaces_list_tables(nextToken = NULL, maxResults = NULL, keyspaceName)The pagination token. To resume pagination, provide the NextToken
value as an argument of a subsequent API invocation.
The total number of tables to return in the output. If the total number
of tables available is more than the value specified, a NextToken is
provided in the output. To resume pagination, provide the NextToken
value as an argument of a subsequent API invocation.
[required] The name of the keyspace.