keyspaces_list_types: The ListTypes operation returns a list of types for a...

View source: R/keyspaces_operations.R

keyspaces_list_typesR Documentation

The ListTypes operation returns a list of types for a specified keyspace

Description

The list_types operation returns a list of types for a specified keyspace.

See https://www.paws-r-sdk.com/docs/keyspaces_list_types/ for full documentation.

Usage

keyspaces_list_types(nextToken = NULL, maxResults = NULL, keyspaceName)

Arguments

nextToken

The pagination token. To resume pagination, provide the NextToken value as an argument of a subsequent API invocation.

maxResults

The total number of types to return in the output. If the total number of types available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as an argument of a subsequent API invocation.

keyspaceName

[required] The name of the keyspace that contains the listed types.


paws.database documentation built on June 1, 2026, 5:08 p.m.