Learn R Programming

paws.database (version 0.2.0)

keyspaces_untag_resource: Removes the association of tags from a Amazon Keyspaces resource

Description

Removes the association of tags from a Amazon Keyspaces resource.

See https://paws-r.github.io/docs/keyspaces/untag_resource.html for full documentation.

Usage

keyspaces_untag_resource(resourceArn, tags)

Arguments

resourceArn

[required] The Amazon Keyspaces resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).

tags

[required] A list of existing tags to be removed from the Amazon Keyspaces resource.