keyspaces_update_keyspace: Adds a new Amazon Web Services Region to the keyspace

View source: R/keyspaces_operations.R

keyspaces_update_keyspaceR Documentation

Adds a new Amazon Web Services Region to the keyspace

Description

Adds a new Amazon Web Services Region to the keyspace. You can add a new Region to a keyspace that is either a single or a multi-Region keyspace. Amazon Keyspaces is going to replicate all tables in the keyspace to the new Region. To successfully replicate all tables to the new Region, they must use client-side timestamps for conflict resolution. To enable client-side timestamps, specify clientSideTimestamps.status = enabled when invoking the API. For more information about client-side timestamps, see Client-side timestamps in Amazon Keyspaces in the Amazon Keyspaces Developer Guide.

See https://www.paws-r-sdk.com/docs/keyspaces_update_keyspace/ for full documentation.

Usage

keyspaces_update_keyspace(
  keyspaceName,
  replicationSpecification,
  clientSideTimestamps = NULL
)

Arguments

keyspaceName

[required] The name of the keyspace.

replicationSpecification

[required] The replication specification of the keyspace includes:

  • regionList - the Amazon Web Services Regions where the keyspace is replicated in.

  • replicationStrategy - the required value is SINGLE_REGION or MULTI_REGION.

clientSideTimestamps

The client-side timestamp setting of the table.

For more information, see How it works: Amazon Keyspaces client-side timestamps in the Amazon Keyspaces Developer Guide.


paws.database documentation built on June 1, 2026, 5:08 p.m.