Attempts to commit the specified transaction. Returns an exception if the transaction was previously aborted. This API action is idempotent if called multiple times for the same transaction.
See https://paws-r.github.io/docs/lakeformation/commit_transaction.html for full documentation.
lakeformation_commit_transaction(TransactionId)[required] The transaction to commit.