lakeformation_delete_lake_formation_opt_in: Remove the Lake Formation permissions enforcement of the...

View source: R/lakeformation_operations.R

lakeformation_delete_lake_formation_opt_inR Documentation

Remove the Lake Formation permissions enforcement of the given databases, tables, and principals

Description

Remove the Lake Formation permissions enforcement of the given databases, tables, and principals.

See https://www.paws-r-sdk.com/docs/lakeformation_delete_lake_formation_opt_in/ for full documentation.

Usage

lakeformation_delete_lake_formation_opt_in(
  Principal,
  Resource,
  Condition = NULL
)

Arguments

Principal

[required] The Lake Formation principal. Supported principals are IAM users or IAM roles.

Resource

[required] A structure for the resource.

Condition

A Lake Formation condition, which applies to permissions and opt-ins that contain an expression.


paws.database documentation built on June 1, 2026, 5:08 p.m.