lakeformation_delete_lf_tag: Deletes an LF-tag by its key name

View source: R/lakeformation_operations.R

lakeformation_delete_lf_tagR Documentation

Deletes an LF-tag by its key name

Description

Deletes an LF-tag by its key name. The operation fails if the specified tag key doesn't exist. When you delete an LF-Tag:

See https://www.paws-r-sdk.com/docs/lakeformation_delete_lf_tag/ for full documentation.

Usage

lakeformation_delete_lf_tag(CatalogId = NULL, TagKey)

Arguments

CatalogId

The identifier for the Data Catalog. By default, the account ID. The Data Catalog is the persistent metadata store. It contains database definitions, table definitions, and other control information to manage your Lake Formation environment.

TagKey

[required] The key-name for the LF-tag to delete.


paws.database documentation built on June 1, 2026, 5:08 p.m.