lakeformation_deregister_resource: Deregisters the resource as managed by the Data Catalog

View source: R/lakeformation_operations.R

lakeformation_deregister_resourceR Documentation

Deregisters the resource as managed by the Data Catalog

Description

Deregisters the resource as managed by the Data Catalog.

See https://www.paws-r-sdk.com/docs/lakeformation_deregister_resource/ for full documentation.

Usage

lakeformation_deregister_resource(ResourceArn)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource that you want to deregister.


paws.database documentation built on June 1, 2026, 5:08 p.m.