Indicates to the service that the specified transaction is still active and should not be treated as idle and aborted.
See https://paws-r.github.io/docs/lakeformation/extend_transaction.html for full documentation.
lakeformation_extend_transaction(TransactionId = NULL)The transaction to extend.