Learn R Programming

paws.database (version 0.2.0)

lakeformation_get_query_statistics: Retrieves statistics on the planning and execution of a query

Description

Retrieves statistics on the planning and execution of a query.

See https://paws-r.github.io/docs/lakeformation/get_query_statistics.html for full documentation.

Usage

lakeformation_get_query_statistics(QueryId)

Arguments

QueryId

[required] The ID of the plan query operation.