lakeformation_get_temporary_data_location_credentials: Allows a user or application in a secure environment to...

View source: R/lakeformation_operations.R

lakeformation_get_temporary_data_location_credentialsR Documentation

Allows a user or application in a secure environment to access data in a specific Amazon S3 location registered with Lake Formation by providing temporary scoped credentials that are limited to the requested data location and the caller's authorized access level

Description

Allows a user or application in a secure environment to access data in a specific Amazon S3 location registered with Lake Formation by providing temporary scoped credentials that are limited to the requested data location and the caller's authorized access level.

See https://www.paws-r-sdk.com/docs/lakeformation_get_temporary_data_location_credentials/ for full documentation.

Usage

lakeformation_get_temporary_data_location_credentials(
  DurationSeconds = NULL,
  AuditContext = NULL,
  DataLocations = NULL,
  CredentialsScope = NULL
)

Arguments

DurationSeconds

The time period, between 900 and 43,200 seconds, for the timeout of the temporary credentials.

AuditContext

A structure used to include auditing information on the privileged API.

DataLocations

The Amazon S3 data location that you want to access.

CredentialsScope

The credential scope is determined by the caller's Lake Formation permission on the associated table. Credential scope can be either:

  • READ - Provides read-only access to the data location.

  • READ_WRITE - Provides both read and write access to the data location.


paws.database documentation built on June 1, 2026, 5:08 p.m.