Learn R Programming

paws.database (version 0.2.0)

lakeformation_get_work_unit_results: Returns the work units resulting from the query

Description

Returns the work units resulting from the query. Work units can be executed in any order and in parallel.

See https://paws-r.github.io/docs/lakeformation/get_work_unit_results.html for full documentation.

Usage

lakeformation_get_work_unit_results(QueryId, WorkUnitId, WorkUnitToken)

Arguments

QueryId

[required] The ID of the plan query operation for which to get results.

WorkUnitId

[required] The work unit ID for which to get results. Value generated by enumerating WorkUnitIdMin to WorkUnitIdMax (inclusive) from the WorkUnitRange in the output of get_work_units.

WorkUnitToken

[required] A work token used to query the execution service. Token output from get_work_units.