Lists the resources registered to be managed by the Data Catalog.
See https://paws-r.github.io/docs/lakeformation/list_resources.html for full documentation.
lakeformation_list_resources(
FilterConditionList = NULL,
MaxResults = NULL,
NextToken = NULL
)Any applicable row-level and/or column-level filtering conditions for the resources.
The maximum number of resource results.
A continuation token, if this is not the first call to retrieve these resources.