Learn R Programming

paws.database (version 0.2.0)

lakeformation_start_transaction: Starts a new transaction and returns its transaction ID

Description

Starts a new transaction and returns its transaction ID. Transaction IDs are opaque objects that you can use to identify a transaction.

See https://paws-r.github.io/docs/lakeformation/start_transaction.html for full documentation.

Usage

lakeformation_start_transaction(TransactionType = NULL)

Arguments

TransactionType

Indicates whether this transaction should be read only or read and write. Writes made using a read-only transaction ID will be rejected. Read-only transactions do not need to be committed.