lakeformation_update_resource: Updates the data access role used for vending access to the...

View source: R/lakeformation_operations.R

lakeformation_update_resourceR Documentation

Updates the data access role used for vending access to the given (registered) resource in Lake Formation

Description

Updates the data access role used for vending access to the given (registered) resource in Lake Formation.

See https://www.paws-r-sdk.com/docs/lakeformation_update_resource/ for full documentation.

Usage

lakeformation_update_resource(
  RoleArn,
  ResourceArn,
  WithFederation = NULL,
  HybridAccessEnabled = NULL,
  ExpectedResourceOwnerAccount = NULL
)

Arguments

RoleArn

[required] The new role to use for the given resource registered in Lake Formation.

ResourceArn

[required] The resource ARN.

WithFederation

Whether or not the resource is a federated resource.

HybridAccessEnabled

Specifies whether the data access of tables pointing to the location can be managed by both Lake Formation permissions as well as Amazon S3 bucket policies.

ExpectedResourceOwnerAccount

The Amazon Web Services account that owns the Glue tables associated with specific Amazon S3 locations.


paws.database documentation built on June 1, 2026, 5:08 p.m.