Learn R Programming

paws.database (version 0.2.0)

lakeformation_update_table_storage_optimizer: Updates the configuration of the storage optimizers for a table

Description

Updates the configuration of the storage optimizers for a table.

See https://paws-r.github.io/docs/lakeformation/update_table_storage_optimizer.html for full documentation.

Usage

lakeformation_update_table_storage_optimizer(
  CatalogId = NULL,
  DatabaseName,
  TableName,
  StorageOptimizerConfig
)

Arguments

CatalogId

The Catalog ID of the table.

DatabaseName

[required] Name of the database where the table is present.

TableName

[required] Name of the table for which to enable the storage optimizer.

StorageOptimizerConfig

[required] Name of the table for which to enable the storage optimizer.