Learn R Programming

paws.database (version 0.2.0)

memorydb_batch_update_cluster: Apply the service update to a list of clusters supplied

Description

Apply the service update to a list of clusters supplied. For more information on service updates and applying them, see Applying the service updates.

See https://paws-r.github.io/docs/memorydb/batch_update_cluster.html for full documentation.

Usage

memorydb_batch_update_cluster(ClusterNames, ServiceUpdate = NULL)

Arguments

ClusterNames

[required] The cluster names to apply the updates.

ServiceUpdate

The unique ID of the service update