Creates an Access Control List. For more information, see Authenticating users with Access Contol Lists (ACLs).
See https://paws-r.github.io/docs/memorydb/create_acl.html for full documentation.
memorydb_create_acl(ACLName, UserNames = NULL, Tags = NULL)[required] The name of the Access Control List.
The list of users that belong to the Access Control List.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.