memorydb_create_multi_region_cluster: Creates a new multi-Region cluster

View source: R/memorydb_operations.R

memorydb_create_multi_region_clusterR Documentation

Creates a new multi-Region cluster

Description

Creates a new multi-Region cluster.

See https://www.paws-r-sdk.com/docs/memorydb_create_multi_region_cluster/ for full documentation.

Usage

memorydb_create_multi_region_cluster(
  MultiRegionClusterNameSuffix,
  Description = NULL,
  Engine = NULL,
  EngineVersion = NULL,
  NodeType,
  MultiRegionParameterGroupName = NULL,
  NumShards = NULL,
  TLSEnabled = NULL,
  Tags = NULL
)

Arguments

MultiRegionClusterNameSuffix

[required] A suffix to be added to the Multi-Region cluster name. Amazon MemoryDB automatically applies a prefix to the Multi-Region cluster Name when it is created. Each Amazon Region has its own prefix. For instance, a Multi-Region cluster Name created in the US-West-1 region will begin with "virxk", along with the suffix name you provide. The suffix guarantees uniqueness of the Multi-Region cluster name across multiple regions.

Description

A description for the multi-Region cluster.

Engine

The name of the engine to be used for the multi-Region cluster.

EngineVersion

The version of the engine to be used for the multi-Region cluster.

NodeType

[required] The node type to be used for the multi-Region cluster.

MultiRegionParameterGroupName

The name of the multi-Region parameter group to be associated with the cluster.

NumShards

The number of shards for the multi-Region cluster.

TLSEnabled

Whether to enable TLS encryption for the multi-Region cluster.

Tags

A list of tags to be applied to the multi-Region cluster.


paws.database documentation built on June 1, 2026, 5:08 p.m.