Creates a copy of an entire cluster at a specific moment in time.
See https://paws-r.github.io/docs/memorydb/create_snapshot.html for full documentation.
memorydb_create_snapshot(
ClusterName,
SnapshotName,
KmsKeyId = NULL,
Tags = NULL
)[required] The snapshot is created from this cluster.
[required] A name for the snapshot being created.
The ID of the KMS key used to encrypt the snapshot.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.