Creates a subnet group. A subnet group is a collection of subnets (typically private) that you can designate for your clusters running in an Amazon Virtual Private Cloud (VPC) environment. When you create a cluster in an Amazon VPC, you must specify a subnet group. MemoryDB uses that subnet group to choose a subnet and IP addresses within that subnet to associate with your nodes. For more information, see Subnets and subnet groups.
See https://paws-r.github.io/docs/memorydb/create_subnet_group.html for full documentation.
memorydb_create_subnet_group(
SubnetGroupName,
Description = NULL,
SubnetIds,
Tags = NULL
)[required] The name of the subnet group.
A description for the subnet group.
[required] A list of VPC subnet IDs for the subnet group.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.