Creates a MemoryDB user. For more information, see Authenticating users with Access Contol Lists (ACLs).
See https://paws-r.github.io/docs/memorydb/create_user.html for full documentation.
memorydb_create_user(UserName, AuthenticationMode, AccessString, Tags = NULL)[required] The name of the user. This value must be unique as it also serves as the user identifier.
[required] Denotes the user's authentication properties, such as whether it requires a password to authenticate.
[required] Access permissions string used for this user.
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.