memorydb_delete_cluster: Deletes a cluster

View source: R/memorydb_operations.R

memorydb_delete_clusterR Documentation

Deletes a cluster

Description

Deletes a cluster. It also deletes all associated nodes and node endpoints.

See https://www.paws-r-sdk.com/docs/memorydb_delete_cluster/ for full documentation.

Usage

memorydb_delete_cluster(
  ClusterName,
  MultiRegionClusterName = NULL,
  FinalSnapshotName = NULL
)

Arguments

ClusterName

[required] The name of the cluster to be deleted

MultiRegionClusterName

The name of the multi-Region cluster to be deleted.

FinalSnapshotName

The user-supplied name of a final cluster snapshot. This is the unique name that identifies the snapshot. MemoryDB creates the snapshot, and then deletes the cluster immediately afterward.


paws.database documentation built on June 1, 2026, 5:08 p.m.