memorydb_describe_multi_region_parameter_groups: Returns a list of multi-region parameter groups

View source: R/memorydb_operations.R

memorydb_describe_multi_region_parameter_groupsR Documentation

Returns a list of multi-region parameter groups

Description

Returns a list of multi-region parameter groups.

See https://www.paws-r-sdk.com/docs/memorydb_describe_multi_region_parameter_groups/ for full documentation.

Usage

memorydb_describe_multi_region_parameter_groups(
  MultiRegionParameterGroupName = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MultiRegionParameterGroupName

The request for information on a specific multi-region parameter group.

MaxResults

The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

NextToken

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.


paws.database documentation built on June 1, 2026, 5:08 p.m.