memorydb_describe_multi_region_parameters: Returns the detailed parameter list for a particular...

View source: R/memorydb_operations.R

memorydb_describe_multi_region_parametersR Documentation

Returns the detailed parameter list for a particular multi-region parameter group

Description

Returns the detailed parameter list for a particular multi-region parameter group.

See https://www.paws-r-sdk.com/docs/memorydb_describe_multi_region_parameters/ for full documentation.

Usage

memorydb_describe_multi_region_parameters(
  MultiRegionParameterGroupName,
  Source = NULL,
  MaxResults = NULL,
  NextToken = NULL
)

Arguments

MultiRegionParameterGroupName

[required] The name of the multi-region parameter group to return details for.

The parameter types to return. Valid values: user | system | engine-default

MaxResults

The maximum number of records to include in the response. If more records exist than the specified MaxResults value, a token is included in the response so that the remaining results can be retrieved.

NextToken

An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token, up to the value specified by MaxResults.


paws.database documentation built on June 1, 2026, 5:08 p.m.