memorydb_tag_resource: Use this operation to add tags to a resource

View source: R/memorydb_operations.R

memorydb_tag_resourceR Documentation

Use this operation to add tags to a resource

Description

Use this operation to add tags to a resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your MemoryDB resources. For more information, see Tagging your MemoryDB resources.

See https://www.paws-r-sdk.com/docs/memorydb_tag_resource/ for full documentation.

Usage

memorydb_tag_resource(ResourceArn, Tags)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource to which the tags are to be added.

Tags

[required] A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted.


paws.database documentation built on June 1, 2026, 5:08 p.m.