memorydb_untag_resource: Use this operation to remove tags on a resource

View source: R/memorydb_operations.R

memorydb_untag_resourceR Documentation

Use this operation to remove tags on a resource

Description

Use this operation to remove tags on a resource. A tag is a key-value pair where the key and value are case-sensitive. You can use tags to categorize and track all your MemoryDB resources. For more information, see Tagging your MemoryDB resources.

See https://www.paws-r-sdk.com/docs/memorydb_untag_resource/ for full documentation.

Usage

memorydb_untag_resource(ResourceArn, TagKeys)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource to which the tags are to be removed.

TagKeys

[required] The list of keys of the tags that are to be removed.


paws.database documentation built on June 1, 2026, 5:08 p.m.