Changes the list of users that belong to the Access Control List.
See https://paws-r.github.io/docs/memorydb/update_acl.html for full documentation.
memorydb_update_acl(ACLName, UserNamesToAdd = NULL, UserNamesToRemove = NULL)[required] The name of the Access Control List
The list of users to add to the Access Control List
The list of users to remove from the Access Control List