memorydb_update_multi_region_cluster: Updates the configuration of an existing multi-Region cluster

View source: R/memorydb_operations.R

memorydb_update_multi_region_clusterR Documentation

Updates the configuration of an existing multi-Region cluster

Description

Updates the configuration of an existing multi-Region cluster.

See https://www.paws-r-sdk.com/docs/memorydb_update_multi_region_cluster/ for full documentation.

Usage

memorydb_update_multi_region_cluster(
  MultiRegionClusterName,
  NodeType = NULL,
  Description = NULL,
  EngineVersion = NULL,
  ShardConfiguration = NULL,
  MultiRegionParameterGroupName = NULL,
  UpdateStrategy = NULL
)

Arguments

MultiRegionClusterName

[required] The name of the multi-Region cluster to be updated.

NodeType

The new node type to be used for the multi-Region cluster.

Description

A new description for the multi-Region cluster.

EngineVersion

The new engine version to be used for the multi-Region cluster.

ShardConfiguration

Shard configuration options. Each shard configuration has the following: Slots and ReplicaCount.

MultiRegionParameterGroupName

The new multi-Region parameter group to be associated with the cluster.

UpdateStrategy

The strategy to use for the update operation. Supported values are "coordinated" or "uncoordinated".


paws.database documentation built on June 1, 2026, 5:08 p.m.