Updates the parameters of a parameter group. You can modify up to 20 parameters in a single request by submitting a list parameter name and value pairs.
See https://paws-r.github.io/docs/memorydb/update_parameter_group.html for full documentation.
memorydb_update_parameter_group(ParameterGroupName, ParameterNameValues)[required] The name of the parameter group to update.
[required] An array of parameter names and values for the parameter update. You must supply at least one parameter name and value; subsequent arguments are optional. A maximum of 20 parameters may be updated per request.