Learn R Programming

paws.database (version 0.2.0)

neptune_add_role_to_db_cluster: Associates an Identity and Access Management (IAM) role with an Neptune DB cluster

Description

Associates an Identity and Access Management (IAM) role with an Neptune DB cluster.

See https://paws-r.github.io/docs/neptune/add_role_to_db_cluster.html for full documentation.

Usage

neptune_add_role_to_db_cluster(
  DBClusterIdentifier,
  RoleArn,
  FeatureName = NULL
)

Arguments

DBClusterIdentifier

[required] The name of the DB cluster to associate the IAM role with.

RoleArn

[required] The Amazon Resource Name (ARN) of the IAM role to associate with the Neptune DB cluster, for example arn:aws:iam::123456789012:role/NeptuneAccessRole.

FeatureName

The name of the feature for the Neptune DB cluster that the IAM role is to be associated with. For the list of supported feature names, see DBEngineVersion.