Creates a new DB cluster parameter group.
See https://paws-r.github.io/docs/neptune/create_db_cluster_parameter_group.html for full documentation.
neptune_create_db_cluster_parameter_group(
DBClusterParameterGroupName,
DBParameterGroupFamily,
Description,
Tags = NULL
)[required] The name of the DB cluster parameter group.
Constraints:
Must match the name of an existing DBClusterParameterGroup.
This value is stored as a lowercase string.
[required] The DB cluster parameter group family name. A DB cluster parameter group can be associated with one and only one DB cluster parameter group family, and can be applied only to a DB cluster running a database engine and engine version compatible with that DB cluster parameter group family.
[required] The description for the DB cluster parameter group.
The tags to be assigned to the new DB cluster parameter group.