Creates a new DB subnet group. DB subnet groups must contain at least one subnet in at least two AZs in the Amazon Region.
See https://paws-r.github.io/docs/neptune/create_db_subnet_group.html for full documentation.
neptune_create_db_subnet_group(
DBSubnetGroupName,
DBSubnetGroupDescription,
SubnetIds,
Tags = NULL
)[required] The name for the DB subnet group. This value is stored as a lowercase string.
Constraints: Must contain no more than 255 letters, numbers, periods, underscores, spaces, or hyphens. Must not be default.
Example: mySubnetgroup
[required] The description for the DB subnet group.
[required] The EC2 Subnet IDs for the DB subnet group.
The tags to be assigned to the new DB subnet group.