Learn R Programming

paws.database (version 0.2.0)

neptune_describe_db_cluster_snapshot_attributes: Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot

Description

Returns a list of DB cluster snapshot attribute names and values for a manual DB cluster snapshot.

See https://paws-r.github.io/docs/neptune/describe_db_cluster_snapshot_attributes.html for full documentation.

Usage

neptune_describe_db_cluster_snapshot_attributes(DBClusterSnapshotIdentifier)

Arguments

DBClusterSnapshotIdentifier

[required] The identifier for the DB cluster snapshot to describe the attributes for.