Learn R Programming

paws.database (version 0.2.0)

neptune_describe_event_categories: Displays a list of categories for all event source types, or, if specified, for a specified source type

Description

Displays a list of categories for all event source types, or, if specified, for a specified source type.

See https://paws-r.github.io/docs/neptune/describe_event_categories.html for full documentation.

Usage

neptune_describe_event_categories(SourceType = NULL, Filters = NULL)

Arguments

SourceType

The type of source that is generating the events.

Valid values: db-instance | db-parameter-group | db-security-group | db-snapshot

Filters

This parameter is not currently supported.