Learn R Programming

paws.database (version 0.2.0)

neptune_describe_global_clusters: Returns information about Neptune global database clusters

Description

Returns information about Neptune global database clusters. This API supports pagination.

See https://paws-r.github.io/docs/neptune/describe_global_clusters.html for full documentation.

Usage

neptune_describe_global_clusters(
  GlobalClusterIdentifier = NULL,
  MaxRecords = NULL,
  Marker = NULL
)

Arguments

GlobalClusterIdentifier

The user-supplied DB cluster identifier. If this parameter is specified, only information about the specified DB cluster is returned. This parameter is not case-sensitive.

Constraints: If supplied, must match an existing DB cluster identifier.

MaxRecords

The maximum number of records to include in the response. If more records exist than the specified MaxRecords value, a pagination marker token is included in the response that you can use to retrieve the remaining results.

Default: 100

Constraints: Minimum 20, maximum 100.

Marker

(Optional) A pagination token returned by a previous call to describe_global_clusters. If this parameter is specified, the response will only include records beyond the marker, up to the number specified by MaxRecords.