neptune_failover_global_cluster: Initiates the failover process for a Neptune global database

View source: R/neptune_operations.R

neptune_failover_global_clusterR Documentation

Initiates the failover process for a Neptune global database

Description

Initiates the failover process for a Neptune global database.

See https://www.paws-r-sdk.com/docs/neptune_failover_global_cluster/ for full documentation.

Usage

neptune_failover_global_cluster(
  GlobalClusterIdentifier,
  TargetDbClusterIdentifier,
  AllowDataLoss = NULL,
  Switchover = NULL
)

Arguments

GlobalClusterIdentifier

[required] Identifier of the Neptune global database that should be failed over. The identifier is the unique key assigned by the user when the Neptune global database was created. In other words, it's the name of the global database that you want to fail over.

Constraints: Must match the identifier of an existing Neptune global database.

TargetDbClusterIdentifier

[required] The Amazon Resource Name (ARN) of the secondary Neptune DB cluster that you want to promote to primary for the global database.

AllowDataLoss

Specifies whether to allow data loss for this global database cluster operation. Allowing data loss triggers a global failover operation.

If you don't specify AllowDataLoss, the global database cluster operation defaults to a switchover.

Constraints: Can't be specified together with the Switchover parameter.

Switchover

Specifies whether to switch over this global database cluster.

Constraints: Can't be specified together with the AllowDataLoss parameter.


paws.database documentation built on June 1, 2026, 5:08 p.m.