View source: R/neptune_operations.R
| neptune_modify_db_instance | R Documentation |
Modifies settings for a DB instance. You can change one or more database configuration parameters by specifying these parameters and the new values in the request. To learn what modifications you can make to your DB instance, call describe_valid_db_instance_modifications before you call modify_db_instance.
See https://www.paws-r-sdk.com/docs/neptune_modify_db_instance/ for full documentation.
neptune_modify_db_instance(
DBInstanceIdentifier,
AllocatedStorage = NULL,
DBInstanceClass = NULL,
DBSubnetGroupName = NULL,
DBSecurityGroups = NULL,
VpcSecurityGroupIds = NULL,
ApplyImmediately = NULL,
MasterUserPassword = NULL,
DBParameterGroupName = NULL,
BackupRetentionPeriod = NULL,
PreferredBackupWindow = NULL,
PreferredMaintenanceWindow = NULL,
MultiAZ = NULL,
EngineVersion = NULL,
AllowMajorVersionUpgrade = NULL,
AutoMinorVersionUpgrade = NULL,
LicenseModel = NULL,
Iops = NULL,
OptionGroupName = NULL,
NewDBInstanceIdentifier = NULL,
StorageType = NULL,
TdeCredentialArn = NULL,
TdeCredentialPassword = NULL,
CACertificateIdentifier = NULL,
Domain = NULL,
CopyTagsToSnapshot = NULL,
MonitoringInterval = NULL,
DBPortNumber = NULL,
PubliclyAccessible = NULL,
MonitoringRoleArn = NULL,
DomainIAMRoleName = NULL,
PromotionTier = NULL,
EnableIAMDatabaseAuthentication = NULL,
EnablePerformanceInsights = NULL,
PerformanceInsightsKMSKeyId = NULL,
CloudwatchLogsExportConfiguration = NULL,
DeletionProtection = NULL
)
DBInstanceIdentifier |
[required] The DB instance identifier. This value is stored as a lowercase string. Constraints:
|
AllocatedStorage |
Not supported by Neptune. |
DBInstanceClass |
The new compute and memory capacity of the DB instance, for example, If you modify the DB instance class, an outage occurs during the change. The change is applied during the next maintenance window, unless Default: Uses existing setting |
DBSubnetGroupName |
The new DB subnet group for the DB instance. You can use this parameter to move your DB instance to a different VPC. Changing the subnet group causes an outage during the change. The change is applied during the next maintenance window, unless you specify Constraints: If supplied, must match the name of an existing DBSubnetGroup. Example: |
DBSecurityGroups |
A list of DB security groups to authorize on this DB instance. Changing this setting doesn't result in an outage and the change is asynchronously applied as soon as possible. Constraints:
|
VpcSecurityGroupIds |
A list of EC2 VPC security groups to authorize on this DB instance. This change is asynchronously applied as soon as possible. Not applicable. The associated list of EC2 VPC security groups is managed by the DB cluster. For more information, see Constraints:
|
ApplyImmediately |
Specifies whether the modifications in this request and any pending modifications are asynchronously applied as soon as possible, regardless of the If this parameter is set to Default: |
MasterUserPassword |
Not supported by Neptune. |
DBParameterGroupName |
The name of the DB parameter group to apply to the DB instance. Changing this setting doesn't result in an outage. The parameter group name itself is changed immediately, but the actual parameter changes are not applied until you reboot the instance without failover. The db instance will NOT be rebooted automatically and the parameter changes will NOT be applied during the next maintenance window. Default: Uses existing setting Constraints: The DB parameter group must be in the same DB parameter group family as this DB instance. |
BackupRetentionPeriod |
Not applicable. The retention period for automated backups is managed by the DB cluster. For more information, see Default: Uses existing setting |
PreferredBackupWindow |
The daily time range during which automated backups are created if automated backups are enabled. Not applicable. The daily time range for creating automated backups is managed by the DB cluster. For more information, see Constraints:
|
PreferredMaintenanceWindow |
The weekly time range (in UTC) during which system maintenance can occur, which might result in an outage. Changing this parameter doesn't result in an outage, except in the following situation, and the change is asynchronously applied as soon as possible. If there are pending actions that cause a reboot, and the maintenance window is changed to include the current time, then changing this parameter will cause a reboot of the DB instance. If moving this window to the current time, there must be at least 30 minutes between the current time and end of the window to ensure pending changes are applied. Default: Uses existing setting Format: ddd:hh24:mi-ddd:hh24:mi Valid Days: Mon | Tue | Wed | Thu | Fri | Sat | Sun Constraints: Must be at least 30 minutes |
MultiAZ |
Specifies if the DB instance is a Multi-AZ deployment. Changing this parameter doesn't result in an outage and the change is applied during the next maintenance window unless the |
EngineVersion |
The version number of the database engine to upgrade to. Currently, setting this parameter has no effect. To upgrade your database engine to the most recent release, use the |
AllowMajorVersionUpgrade |
Indicates that major version upgrades are allowed. Changing this parameter doesn't result in an outage and the change is asynchronously applied as soon as possible. |
AutoMinorVersionUpgrade |
Indicates that minor version upgrades are applied automatically to the DB instance during the maintenance window. Changing this parameter doesn't result in an outage except in the following case and the change is asynchronously applied as soon as possible. An outage will result if this parameter is set to |
LicenseModel |
Not supported by Neptune. |
Iops |
The new Provisioned IOPS (I/O operations per second) value for the instance. Changing this setting doesn't result in an outage and the change is applied during the next maintenance window unless the Default: Uses existing setting |
OptionGroupName |
(Not supported by Neptune) |
NewDBInstanceIdentifier |
The new DB instance identifier for the DB instance when renaming a DB instance. When you change the DB instance identifier, an instance reboot will occur immediately if you set Constraints:
Example: |
StorageType |
Not applicable. In Neptune the storage type is managed at the DB Cluster level. |
TdeCredentialArn |
The ARN from the key store with which to associate the instance for TDE encryption. |
TdeCredentialPassword |
The password for the given ARN from the key store in order to access the device. |
CACertificateIdentifier |
Indicates the certificate that needs to be associated with the instance. |
Domain |
Not supported. |
CopyTagsToSnapshot |
True to copy all tags from the DB instance to snapshots of the DB instance, and otherwise false. The default is false. |
MonitoringInterval |
The interval, in seconds, between points when Enhanced Monitoring metrics are collected for the DB instance. To disable collecting Enhanced Monitoring metrics, specify 0. The default is 0. If Valid Values: |
DBPortNumber |
The port number on which the database accepts connections. The value of the Your database will restart when you change the Default: |
PubliclyAccessible |
Indicates whether the DB instance is publicly accessible. When the DB instance is publicly accessible and you connect from outside of the DB instance's virtual private cloud (VPC), its Domain Name System (DNS) endpoint resolves to the public IP address. When you connect from within the same VPC as the DB instance, the endpoint resolves to the private IP address. Access to the DB instance is ultimately controlled by the security group it uses. That public access isn't permitted if the security group assigned to the DB cluster doesn't permit it. When the DB instance isn't publicly accessible, it is an internal DB instance with a DNS name that resolves to a private IP address. |
MonitoringRoleArn |
The ARN for the IAM role that permits Neptune to send enhanced monitoring metrics to Amazon CloudWatch Logs. For example, If |
DomainIAMRoleName |
Not supported |
PromotionTier |
A value that specifies the order in which a Read Replica is promoted to the primary instance after a failure of the existing primary instance. Default: 1 Valid Values: 0 - 15 |
EnableIAMDatabaseAuthentication |
True to enable mapping of Amazon Identity and Access Management (IAM) accounts to database accounts, and otherwise false. You can enable IAM database authentication for the following database engines Not applicable. Mapping Amazon IAM accounts to database accounts is managed by the DB cluster. For more information, see Default: |
EnablePerformanceInsights |
(Not supported by Neptune) |
PerformanceInsightsKMSKeyId |
(Not supported by Neptune) |
CloudwatchLogsExportConfiguration |
The configuration setting for the log types to be enabled for export to CloudWatch Logs for a specific DB instance or DB cluster. |
DeletionProtection |
A value that indicates whether the DB instance has deletion protection enabled. The database can't be deleted when deletion protection is enabled. By default, deletion protection is disabled. See Deleting a DB Instance. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.