Learn R Programming

paws.database (version 0.2.0)

neptune_remove_source_identifier_from_subscription: Removes a source identifier from an existing event notification subscription

Description

Removes a source identifier from an existing event notification subscription.

See https://paws-r.github.io/docs/neptune/remove_source_identifier_from_subscription.html for full documentation.

Usage

neptune_remove_source_identifier_from_subscription(
  SubscriptionName,
  SourceIdentifier
)

Arguments

SubscriptionName

[required] The name of the event notification subscription you want to remove a source identifier from.

SourceIdentifier

[required] The source identifier to be removed from the subscription, such as the DB instance identifier for a DB instance or the name of a security group.