Learn R Programming

paws.database (version 0.2.0)

neptune_start_db_cluster: Starts an Amazon Neptune DB cluster that was stopped using the Amazon console, the Amazon CLI stop-db-cluster command, or the StopDBCluster API

Description

Starts an Amazon Neptune DB cluster that was stopped using the Amazon console, the Amazon CLI stop-db-cluster command, or the StopDBCluster API.

See https://paws-r.github.io/docs/neptune/start_db_cluster.html for full documentation.

Usage

neptune_start_db_cluster(DBClusterIdentifier)

Arguments

DBClusterIdentifier

[required] The DB cluster identifier of the Neptune DB cluster to be started. This parameter is stored as a lowercase string.