View source: R/neptune_operations.R
| neptune_switchover_global_cluster | R Documentation |
Switches over the specified secondary DB cluster to be the new primary DB cluster in the global database cluster. Switchover operations were previously called "managed planned failovers."
See https://www.paws-r-sdk.com/docs/neptune_switchover_global_cluster/ for full documentation.
neptune_switchover_global_cluster(
GlobalClusterIdentifier,
TargetDbClusterIdentifier
)
GlobalClusterIdentifier |
[required] The identifier of the global database cluster to switch over. This parameter isn't case-sensitive. Constraints: Must match the identifier of an existing global database cluster. |
TargetDbClusterIdentifier |
[required] The Amazon Resource Name (ARN) of the secondary Neptune DB cluster that you want to promote to primary for the global database. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.