Learn R Programming

paws.database (version 0.2.0)

qldb_describe_journal_s3_export: Returns information about a journal export job, including the ledger name, export ID, creation time, current status, and the parameters of the original export creation request

Description

Returns information about a journal export job, including the ledger name, export ID, creation time, current status, and the parameters of the original export creation request.

See https://paws-r.github.io/docs/qldb/describe_journal_s3_export.html for full documentation.

Usage

qldb_describe_journal_s3_export(Name, ExportId)

Arguments

Name

[required] The name of the ledger.

ExportId

[required] The UUID (represented in Base62-encoded text) of the journal export job to describe.