Returns information about a ledger, including its state, permissions mode, encryption at rest settings, and when it was created.
See https://paws-r.github.io/docs/qldb/describe_ledger.html for full documentation.
qldb_describe_ledger(Name)[required] The name of the ledger that you want to describe.