Learn R Programming

paws.database (version 0.2.0)

qldb_get_block: Returns a block object at a specified address in a journal

Description

Returns a block object at a specified address in a journal. Also returns a proof of the specified block for verification if DigestTipAddress is provided.

See https://paws-r.github.io/docs/qldb/get_block.html for full documentation.

Usage

qldb_get_block(Name, BlockAddress, DigestTipAddress = NULL)

Arguments

Name

[required] The name of the ledger.

BlockAddress

[required] The location of the block that you want to request. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo.

For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:14}.

DigestTipAddress

The latest block location covered by the digest for which to request a proof. An address is an Amazon Ion structure that has two fields: strandId and sequenceNo.

For example: {strandId:"BlFTjlSXze9BIh1KOszcE3",sequenceNo:49}.