Returns an array of journal export job descriptions for all ledgers that are associated with the current Amazon Web Services account and Region.
See https://paws-r.github.io/docs/qldb/list_journal_s3_exports.html for full documentation.
qldb_list_journal_s3_exports(MaxResults = NULL, NextToken = NULL)The maximum number of results to return in a single
list_journal_s3_exports request. (The
actual number of results returned might be fewer.)
A pagination token, indicating that you want to retrieve the next page
of results. If you received a value for NextToken in the response from
a previous list_journal_s3_exports
call, then you should use that value as input here.