Sends a command to an Amazon QLDB ledger.
See https://paws-r.github.io/docs/qldbsession/send_command.html for full documentation.
qldbsession_send_command(
SessionToken = NULL,
StartSession = NULL,
StartTransaction = NULL,
EndSession = NULL,
CommitTransaction = NULL,
AbortTransaction = NULL,
ExecuteStatement = NULL,
FetchPage = NULL
)Specifies the session token for the current command. A session token is constant throughout the life of the session.
To obtain a session token, run the StartSession command. This
SessionToken is required for every subsequent command that is issued
during the current session.
Command to start a new session. A session token is obtained as part of the response.
Command to start a new transaction.
Command to end the current session.
Command to commit the specified transaction.
Command to abort the current transaction.
Command to execute a statement in the specified transaction.
Command to fetch a page.