Adds a source identifier to an existing RDS event notification subscription.
See https://paws-r.github.io/docs/rds/add_source_identifier_to_subscription.html for full documentation.
rds_add_source_identifier_to_subscription(SubscriptionName, SourceIdentifier)[required] The name of the RDS event notification subscription you want to add a source identifier to.
[required] The identifier of the event source to be added.
Constraints:
If the source type is a DB instance, a DBInstanceIdentifier value
must be supplied.
If the source type is a DB cluster, a DBClusterIdentifier value
must be supplied.
If the source type is a DB parameter group, a DBParameterGroupName
value must be supplied.
If the source type is a DB security group, a DBSecurityGroupName
value must be supplied.
If the source type is a DB snapshot, a DBSnapshotIdentifier value
must be supplied.
If the source type is a DB cluster snapshot, a
DBClusterSnapshotIdentifier value must be supplied.
If the source type is an RDS Proxy, a DBProxyName value must be
supplied.