rds_copy_db_parameter_group: Copies the specified DB parameter group

View source: R/rds_operations.R

rds_copy_db_parameter_groupR Documentation

Copies the specified DB parameter group

Description

Copies the specified DB parameter group.

See https://www.paws-r-sdk.com/docs/rds_copy_db_parameter_group/ for full documentation.

Usage

rds_copy_db_parameter_group(
  SourceDBParameterGroupIdentifier,
  TargetDBParameterGroupIdentifier,
  TargetDBParameterGroupDescription,
  Tags = NULL
)

Arguments

SourceDBParameterGroupIdentifier

[required] The identifier or ARN for the source DB parameter group. For information about creating an ARN, see Constructing an ARN for Amazon RDS in the Amazon RDS User Guide.

Constraints:

  • Must specify a valid DB parameter group.

TargetDBParameterGroupIdentifier

[required] The identifier for the copied DB parameter group.

Constraints:

  • Can't be null, empty, or blank

  • Must contain from 1 to 255 letters, numbers, or hyphens

  • First character must be a letter

  • Can't end with a hyphen or contain two consecutive hyphens

Example: my-db-parameter-group

TargetDBParameterGroupDescription

[required] A description for the copied DB parameter group.

Tags

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.


paws.database documentation built on June 1, 2026, 5:08 p.m.