View source: R/rds_operations.R
| rds_copy_db_snapshot | R Documentation |
Copies the specified DB snapshot. The source DB snapshot must be in the available state.
See https://www.paws-r-sdk.com/docs/rds_copy_db_snapshot/ for full documentation.
rds_copy_db_snapshot(
SourceDBSnapshotIdentifier,
TargetDBSnapshotIdentifier,
KmsKeyId = NULL,
Tags = NULL,
CopyTags = NULL,
PreSignedUrl = NULL,
OptionGroupName = NULL,
TargetCustomAvailabilityZone = NULL,
SnapshotTarget = NULL,
CopyOptionGroup = NULL,
SnapshotAvailabilityZone = NULL
)
SourceDBSnapshotIdentifier |
[required] The identifier for the source DB snapshot. If the source snapshot is in the same Amazon Web Services Region as the copy, specify a valid DB snapshot identifier. For example, you might specify If you are copying from a shared manual DB snapshot, this parameter must be the Amazon Resource Name (ARN) of the shared DB snapshot. If the source snapshot is in a different Amazon Web Services Region than the copy, specify a valid DB snapshot ARN. You can also specify an ARN of a snapshot that is in a different account and a different Amazon Web Services Region. For example, you might specify Constraints:
Example: Example: |
TargetDBSnapshotIdentifier |
[required] The identifier for the copy of the snapshot. Constraints:
Example: |
KmsKeyId |
The Amazon Web Services KMS key identifier for an encrypted DB snapshot. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. If you copy an encrypted DB snapshot from your Amazon Web Services account, you can specify a value for this parameter to encrypt the copy with a new KMS key. If you don't specify a value for this parameter, then the copy of the DB snapshot is encrypted with the same Amazon Web Services KMS key as the source DB snapshot. If you copy an encrypted DB snapshot that is shared from another Amazon Web Services account, then you must specify a value for this parameter. If you specify this parameter when you copy an unencrypted snapshot, the copy is encrypted. If you copy an encrypted snapshot to a different Amazon Web Services Region, then you must specify an Amazon Web Services KMS key identifier for the destination Amazon Web Services Region. KMS keys are specific to the Amazon Web Services Region that they are created in, and you can't use KMS keys from one Amazon Web Services Region in another Amazon Web Services Region. |
Tags |
A list of tags. For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide. |
CopyTags |
Specifies whether to copy all tags from the source DB snapshot to the target DB snapshot. By default, tags aren't copied. |
PreSignedUrl |
When you are copying a snapshot from one Amazon Web Services GovCloud (US) Region to another, the URL that contains a Signature Version 4 signed request for the This setting applies only to Amazon Web Services GovCloud (US) Regions. It's ignored in other Amazon Web Services Regions. You must specify this parameter when you copy an encrypted DB snapshot from another Amazon Web Services Region by using the Amazon RDS API. Don't specify The presigned URL must be a valid request for the
To learn how to generate a Signature Version 4 signed request, see Authenticating Requests: Using Query Parameters (Amazon Web Services Signature Version 4) and Signature Version 4 Signing Process. If you are using an Amazon Web Services SDK tool or the CLI, you can specify |
OptionGroupName |
The name of an option group to associate with the copy of the snapshot. Specify this option if you are copying a snapshot from one Amazon Web Services Region to another, and your DB instance uses a nondefault option group. If your source DB instance uses Transparent Data Encryption for Oracle or Microsoft SQL Server, you must specify this option when copying across Amazon Web Services Regions. For more information, see Option group considerations in the Amazon RDS User Guide. |
TargetCustomAvailabilityZone |
The external custom Availability Zone (CAZ) identifier for the target CAZ. Example: |
SnapshotTarget |
Configures the location where RDS will store copied snapshots. Valid Values:
|
CopyOptionGroup |
Specifies whether to copy the DB option group associated with the source DB snapshot to the target Amazon Web Services account and associate with the target DB snapshot. The associated option group can be copied only with cross-account snapshot copy calls. |
SnapshotAvailabilityZone |
Specifies the name of the Availability Zone where RDS stores the DB snapshot. This value is valid only for snapshots that RDS stores on a Dedicated Local Zone. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.