rds_copy_option_group: Copies the specified option group

View source: R/rds_operations.R

rds_copy_option_groupR Documentation

Copies the specified option group

Description

Copies the specified option group.

See https://www.paws-r-sdk.com/docs/rds_copy_option_group/ for full documentation.

Usage

rds_copy_option_group(
  SourceOptionGroupIdentifier,
  TargetOptionGroupIdentifier,
  TargetOptionGroupDescription,
  Tags = NULL
)

Arguments

SourceOptionGroupIdentifier

[required] The identifier for the source option group.

Constraints:

  • Must specify a valid option group.

TargetOptionGroupIdentifier

[required] The identifier for the copied option group.

Constraints:

  • Can't be null, empty, or blank

  • Must contain from 1 to 255 letters, numbers, or hyphens

  • First character must be a letter

  • Can't end with a hyphen or contain two consecutive hyphens

Example: my-option-group

TargetOptionGroupDescription

[required] The description for the copied option group.

Tags

A list of tags.

For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide.


paws.database documentation built on June 1, 2026, 5:08 p.m.