Learn R Programming

paws.database (version 0.2.0)

rds_create_custom_db_engine_version: Creates a custom DB engine version (CEV)

Description

Creates a custom DB engine version (CEV). A CEV is a binary volume snapshot of a database engine and specific AMI. The supported engines are the following:

See https://paws-r.github.io/docs/rds/create_custom_db_engine_version.html for full documentation.

Usage

rds_create_custom_db_engine_version(
  Engine,
  EngineVersion,
  DatabaseInstallationFilesS3BucketName,
  DatabaseInstallationFilesS3Prefix = NULL,
  KMSKeyId,
  Description = NULL,
  Manifest,
  Tags = NULL
)

Arguments

Engine

[required] The database engine to use for your custom engine version (CEV). The only supported value is custom-oracle-ee.

EngineVersion

[required] The name of your CEV. The name format is 19.customized_string . For example, a valid name is 19.my_cev1. This setting is required for RDS Custom for Oracle, but optional for Amazon RDS. The combination of Engine and EngineVersion is unique per customer per Region.

DatabaseInstallationFilesS3BucketName

[required] The name of an Amazon S3 bucket that contains database installation files for your CEV. For example, a valid bucket name is my-custom-installation-files.

DatabaseInstallationFilesS3Prefix

The Amazon S3 directory that contains the database installation files for your CEV. For example, a valid bucket name is 123456789012/cev1. If this setting isn't specified, no prefix is assumed.

KMSKeyId

[required] The Amazon Web Services KMS key identifier for an encrypted CEV. A symmetric KMS key is required for RDS Custom, but optional for Amazon RDS.

If you have an existing symmetric KMS key in your account, you can use it with RDS Custom. No further action is necessary. If you don't already have a symmetric KMS key in your account, follow the instructions in Creating symmetric KMS keys in the Amazon Web Services Key Management Service Developer Guide.

You can choose the same symmetric key when you create a CEV and a DB instance, or choose different keys.

Description

An optional description of your CEV.

Manifest

[required] The CEV manifest, which is a JSON document that describes the installation .zip files stored in Amazon S3. Specify the name/value pairs in a file or a quoted string. RDS Custom applies the patches in the order in which they are listed.

The following JSON fields are valid:

MediaImportTemplateVersion

Version of the CEV manifest. The date is in the format YYYY-MM-DD.

databaseInstallationFileNames

Ordered list of installation files for the CEV.

opatchFileNames

Ordered list of OPatch installers used for the Oracle DB engine.

psuRuPatchFileNames

The PSU and RU patches for this CEV.

OtherPatchFileNames

The patches that are not in the list of PSU and RU patches. Amazon RDS applies these patches after applying the PSU and RU patches.

For more information, see Creating the CEV manifest in the Amazon RDS User Guide.

Tags