View source: R/rds_operations.R
| rds_create_db_proxy | R Documentation |
Creates a new DB proxy.
See https://www.paws-r-sdk.com/docs/rds_create_db_proxy/ for full documentation.
rds_create_db_proxy(
DBProxyName,
EngineFamily,
DefaultAuthScheme = NULL,
Auth = NULL,
RoleArn,
VpcSubnetIds,
VpcSecurityGroupIds = NULL,
RequireTLS = NULL,
IdleClientTimeout = NULL,
DebugLogging = NULL,
Tags = NULL,
EndpointNetworkType = NULL,
TargetConnectionNetworkType = NULL
)
DBProxyName |
[required] The identifier for the proxy. This name must be unique for all proxies owned by your Amazon Web Services account in the specified Amazon Web Services Region. An identifier must begin with a letter and must contain only ASCII letters, digits, and hyphens; it can't end with a hyphen or contain two consecutive hyphens. |
EngineFamily |
[required] The kinds of databases that the proxy can connect to. This value determines which database network protocol the proxy recognizes when it interprets network traffic to and from the database. For Aurora MySQL, RDS for MariaDB, and RDS for MySQL databases, specify |
DefaultAuthScheme |
The default authentication scheme that the proxy uses for client connections to the proxy and connections from the proxy to the underlying database. Valid values are |
Auth |
The authorization mechanism that the proxy uses. |
RoleArn |
[required] The Amazon Resource Name (ARN) of the IAM role that the proxy uses to access secrets in Amazon Web Services Secrets Manager. |
VpcSubnetIds |
[required] One or more VPC subnet IDs to associate with the new proxy. |
VpcSecurityGroupIds |
One or more VPC security group IDs to associate with the new proxy. |
RequireTLS |
Specifies whether Transport Layer Security (TLS) encryption is required for connections to the proxy. By enabling this setting, you can enforce encrypted TLS connections to the proxy. |
IdleClientTimeout |
The number of seconds that a connection to the proxy can be inactive before the proxy disconnects it. You can set this value higher or lower than the connection timeout limit for the associated database. |
DebugLogging |
Specifies whether the proxy logs detailed connection and query information. When you enable |
Tags |
An optional set of key-value pairs to associate arbitrary data of your choosing with the proxy. |
EndpointNetworkType |
The network type of the DB proxy endpoint. The network type determines the IP version that the proxy endpoint supports. Valid values:
Default: Constraints:
|
TargetConnectionNetworkType |
The network type that the proxy uses to connect to the target database. The network type determines the IP version that the proxy uses for connections to the database. Valid values:
Default: Constraints:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.