View source: R/rds_operations.R
| rds_create_db_proxy_endpoint | R Documentation |
Creates a DBProxyEndpoint. Only applies to proxies that are associated with Aurora DB clusters. You can use DB proxy endpoints to specify read/write or read-only access to the DB cluster. You can also use DB proxy endpoints to access a DB proxy through a different VPC than the proxy's default VPC.
See https://www.paws-r-sdk.com/docs/rds_create_db_proxy_endpoint/ for full documentation.
rds_create_db_proxy_endpoint(
DBProxyName,
DBProxyEndpointName,
VpcSubnetIds,
VpcSecurityGroupIds = NULL,
TargetRole = NULL,
Tags = NULL,
EndpointNetworkType = NULL
)
DBProxyName |
[required] The name of the DB proxy associated with the DB proxy endpoint that you create. |
DBProxyEndpointName |
[required] The name of the DB proxy endpoint to create. |
VpcSubnetIds |
[required] The VPC subnet IDs for the DB proxy endpoint that you create. You can specify a different set of subnet IDs than for the original DB proxy. |
VpcSecurityGroupIds |
The VPC security group IDs for the DB proxy endpoint that you create. You can specify a different set of security group IDs than for the original DB proxy. The default is the default security group for the VPC. |
TargetRole |
The role of the DB proxy endpoint. The role determines whether the endpoint can be used for read/write or only read operations. The default is |
Tags |
A list of tags. For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide. |
EndpointNetworkType |
The network type of the DB proxy endpoint. The network type determines the IP version that the proxy endpoint supports. Valid values:
Default: Constraints:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.