View source: R/rds_operations.R
| rds_create_db_snapshot | R Documentation |
Creates a snapshot of a DB instance. The source DB instance must be in the available or storage-optimization state.
See https://www.paws-r-sdk.com/docs/rds_create_db_snapshot/ for full documentation.
rds_create_db_snapshot(DBSnapshotIdentifier, DBInstanceIdentifier, Tags = NULL)
DBSnapshotIdentifier |
[required] The identifier for the DB snapshot. Constraints:
Example: |
DBInstanceIdentifier |
[required] The identifier of the DB instance that you want to create the snapshot of. Constraints:
|
Tags |
A list of tags. For more information, see Tagging Amazon RDS resources in the Amazon RDS User Guide or Tagging Amazon Aurora and Amazon RDS resources in the Amazon Aurora User Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.