Learn R Programming

paws.database (version 0.2.0)

rds_delete_custom_db_engine_version: Deletes a custom engine version

Description

Deletes a custom engine version. To run this command, make sure you meet the following prerequisites:

See https://paws-r.github.io/docs/rds/delete_custom_db_engine_version.html for full documentation.

Usage

rds_delete_custom_db_engine_version(Engine, EngineVersion)

Arguments

Engine

[required] The database engine. The only supported engine is custom-oracle-ee.

EngineVersion

[required] The custom engine version (CEV) for your DB instance. This option is required for RDS Custom, but optional for Amazon RDS. The combination of Engine and EngineVersion is unique per customer per Amazon Web Services Region.