View source: R/rds_operations.R
| rds_delete_db_cluster | R Documentation |
The DeleteDBCluster action deletes a previously provisioned DB cluster. When you delete a DB cluster, all automated backups for that DB cluster are deleted and can't be recovered. Manual DB cluster snapshots of the specified DB cluster are not deleted.
See https://www.paws-r-sdk.com/docs/rds_delete_db_cluster/ for full documentation.
rds_delete_db_cluster(
DBClusterIdentifier,
SkipFinalSnapshot = NULL,
FinalDBSnapshotIdentifier = NULL,
DeleteAutomatedBackups = NULL
)
DBClusterIdentifier |
[required] The DB cluster identifier for the DB cluster to be deleted. This parameter isn't case-sensitive. Constraints:
|
SkipFinalSnapshot |
Specifies whether to skip the creation of a final DB cluster snapshot before RDS deletes the DB cluster. If you set this value to If |
FinalDBSnapshotIdentifier |
The DB cluster snapshot identifier of the new DB cluster snapshot created when If you specify this parameter and also skip the creation of a final DB cluster snapshot with the Constraints:
|
DeleteAutomatedBackups |
Specifies whether to remove automated backups immediately after the DB cluster is deleted. This parameter isn't case-sensitive. The default is to remove automated backups immediately after the DB cluster is deleted, unless the Amazon Web Services Backup policy specifies a point-in-time restore rule. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.