Learn R Programming

paws.database (version 0.2.0)

rds_delete_db_cluster_endpoint: Deletes a custom endpoint and removes it from an Amazon Aurora DB cluster

Description

Deletes a custom endpoint and removes it from an Amazon Aurora DB cluster.

See https://paws-r.github.io/docs/rds/delete_db_cluster_endpoint.html for full documentation.

Usage

rds_delete_db_cluster_endpoint(DBClusterEndpointIdentifier)

Arguments

DBClusterEndpointIdentifier

[required] The identifier associated with the custom endpoint. This parameter is stored as a lowercase string.