Learn R Programming

paws.database (version 0.2.0)

rds_delete_db_proxy_endpoint: Deletes a DBProxyEndpoint

Description

Deletes a DBProxyEndpoint. Doing so removes the ability to access the DB proxy using the endpoint that you defined. The endpoint that you delete might have provided capabilities such as read/write or read-only operations, or using a different VPC than the DB proxy's default VPC.

See https://paws-r.github.io/docs/rds/delete_db_proxy_endpoint.html for full documentation.

Usage

rds_delete_db_proxy_endpoint(DBProxyEndpointName)

Arguments

DBProxyEndpointName

[required] The name of the DB proxy endpoint to delete.