rds_describe_db_major_engine_versions: Describes the properties of specific major versions of DB...

View source: R/rds_operations.R

rds_describe_db_major_engine_versionsR Documentation

Describes the properties of specific major versions of DB engines

Description

Describes the properties of specific major versions of DB engines.

See https://www.paws-r-sdk.com/docs/rds_describe_db_major_engine_versions/ for full documentation.

Usage

rds_describe_db_major_engine_versions(
  Engine = NULL,
  MajorEngineVersion = NULL,
  Marker = NULL,
  MaxRecords = NULL
)

Arguments

Engine

The database engine to return major version details for.

Valid Values:

  • aurora-mysql

  • aurora-postgresql

  • custom-sqlserver-ee

  • custom-sqlserver-se

  • custom-sqlserver-web

  • db2-ae

  • db2-se

  • mariadb

  • mysql

  • oracle-ee

  • oracle-ee-cdb

  • oracle-se2

  • oracle-se2-cdb

  • postgres

  • sqlserver-ee

  • sqlserver-se

  • sqlserver-ex

  • sqlserver-web

MajorEngineVersion

A specific database major engine version to return details for.

Example: 8.4

Marker

An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by MaxRecords.

MaxRecords

The maximum number of records to include in the response. If more than the MaxRecords value is available, a pagination token called a marker is included in the response so you can retrieve the remaining results.

Default: 100


paws.database documentation built on June 1, 2026, 5:08 p.m.