View source: R/rds_operations.R
| rds_describe_db_shard_groups | R Documentation |
Describes existing Aurora Limitless Database DB shard groups.
See https://www.paws-r-sdk.com/docs/rds_describe_db_shard_groups/ for full documentation.
rds_describe_db_shard_groups(
DBShardGroupIdentifier = NULL,
Filters = NULL,
Marker = NULL,
MaxRecords = NULL
)
DBShardGroupIdentifier |
The user-supplied DB shard group identifier. If this parameter is specified, information for only the specific DB shard group is returned. This parameter isn't case-sensitive. Constraints:
|
Filters |
A filter that specifies one or more DB shard groups to describe. |
Marker |
An optional pagination token provided by a previous |
MaxRecords |
The maximum number of records to include in the response. If more records exist than the specified Default: 100 Constraints: Minimum 20, maximum 100 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.