Learn R Programming

paws.database (version 0.2.0)

rds_describe_db_snapshot_attributes: Returns a list of DB snapshot attribute names and values for a manual DB snapshot

Description

Returns a list of DB snapshot attribute names and values for a manual DB snapshot.

See https://paws-r.github.io/docs/rds/describe_db_snapshot_attributes.html for full documentation.

Usage

rds_describe_db_snapshot_attributes(DBSnapshotIdentifier)

Arguments

DBSnapshotIdentifier

[required] The identifier for the DB snapshot to describe the attributes for.