View source: R/rds_operations.R
| rds_describe_serverless_v2_platform_versions | R Documentation |
Describes the properties of specific platform versions for Aurora Serverless v2.
See https://www.paws-r-sdk.com/docs/rds_describe_serverless_v2_platform_versions/ for full documentation.
rds_describe_serverless_v2_platform_versions(
ServerlessV2PlatformVersion = NULL,
Engine = NULL,
Filters = NULL,
DefaultOnly = NULL,
IncludeAll = NULL,
MaxRecords = NULL,
Marker = NULL
)
ServerlessV2PlatformVersion |
A specific platform version to return details for. Example: |
Engine |
The database engine to return platform version details for. Valid Values:
|
Filters |
This parameter isn't currently supported. |
DefaultOnly |
Specifies whether to return only the default platform versions for each engine. The default platform version is the version used for new DB clusters. |
IncludeAll |
Specifies whether to also include platform versions which are no longer in use. |
MaxRecords |
The maximum number of records to include in the response. If more than the Default: 20 Constraints: Minimum 1, maximum 200. |
Marker |
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.