rds_remove_from_global_cluster: Detaches an Aurora secondary cluster from an Aurora global...

View source: R/rds_operations.R

rds_remove_from_global_clusterR Documentation

Detaches an Aurora secondary cluster from an Aurora global database cluster

Description

Detaches an Aurora secondary cluster from an Aurora global database cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary cluster in a different Region.

See https://www.paws-r-sdk.com/docs/rds_remove_from_global_cluster/ for full documentation.

Usage

rds_remove_from_global_cluster(GlobalClusterIdentifier, DbClusterIdentifier)

Arguments

GlobalClusterIdentifier

[required] The cluster identifier to detach from the Aurora global database cluster.

DbClusterIdentifier

[required] The Amazon Resource Name (ARN) identifying the cluster that was detached from the Aurora global database cluster.


paws.database documentation built on June 1, 2026, 5:08 p.m.