Learn R Programming

paws.database (version 0.2.0)

rds_remove_role_from_db_cluster: Removes the asssociation of an Amazon Web Services Identity and Access Management (IAM) role from a DB cluster

Description

Removes the asssociation of an Amazon Web Services Identity and Access Management (IAM) role from a DB cluster.

See https://paws-r.github.io/docs/rds/remove_role_from_db_cluster.html for full documentation.

Usage

rds_remove_role_from_db_cluster(
  DBClusterIdentifier,
  RoleArn,
  FeatureName = NULL
)

Arguments

DBClusterIdentifier

[required] The name of the DB cluster to disassociate the IAM role from.

RoleArn

[required] The Amazon Resource Name (ARN) of the IAM role to disassociate from the Aurora DB cluster, for example arn:aws:iam::123456789012:role/AuroraAccessRole.

FeatureName

The name of the feature for the DB cluster that the IAM role is to be disassociated from. For information about supported feature names, see DBEngineVersion.