Learn R Programming

paws.database (version 0.2.0)

rds_start_db_cluster: Starts an Amazon Aurora DB cluster that was stopped using the Amazon Web Services console, the stop-db-cluster CLI command, or the StopDBCluster action

Description

Starts an Amazon Aurora DB cluster that was stopped using the Amazon Web Services console, the stop-db-cluster CLI command, or the StopDBCluster action.

See https://paws-r.github.io/docs/rds/start_db_cluster.html for full documentation.

Usage

rds_start_db_cluster(DBClusterIdentifier)

Arguments

DBClusterIdentifier

[required] The DB cluster identifier of the Amazon Aurora DB cluster to be started. This parameter is stored as a lowercase string.