Learn R Programming

paws.database (version 0.2.0)

rds_start_export_task: Starts an export of a snapshot to Amazon S3

Description

Starts an export of a snapshot to Amazon S3. The provided IAM role must have access to the S3 bucket.

See https://paws-r.github.io/docs/rds/start_export_task.html for full documentation.

Usage

rds_start_export_task(
  ExportTaskIdentifier,
  SourceArn,
  S3BucketName,
  IamRoleArn,
  KmsKeyId,
  S3Prefix = NULL,
  ExportOnly = NULL
)

Arguments

ExportTaskIdentifier

[required] A unique identifier for the snapshot export task. This ID isn't an identifier for the Amazon S3 bucket where the snapshot is to be exported to.

SourceArn

[required] The Amazon Resource Name (ARN) of the snapshot to export to Amazon S3.

S3BucketName

[required] The name of the Amazon S3 bucket to export the snapshot to.

IamRoleArn

[required] The name of the IAM role to use for writing to the Amazon S3 bucket when exporting a snapshot.

KmsKeyId

[required] The ID of the Amazon Web Services KMS key to use to encrypt the snapshot exported to Amazon S3. The Amazon Web Services KMS key identifier is the key ARN, key ID, alias ARN, or alias name for the KMS key. The caller of this operation must be authorized to execute the following operations. These can be set in the Amazon Web Services KMS key policy:

  • GrantOperation.Encrypt

  • GrantOperation.Decrypt

  • GrantOperation.GenerateDataKey

  • GrantOperation.GenerateDataKeyWithoutPlaintext

  • GrantOperation.ReEncryptFrom

  • GrantOperation.ReEncryptTo

  • GrantOperation.CreateGrant

  • GrantOperation.DescribeKey

  • GrantOperation.RetireGrant

S3Prefix

The Amazon S3 bucket prefix to use as the file name and path of the exported snapshot.

ExportOnly

The data to be exported from the snapshot. If this parameter is not provided, all the snapshot data is exported. Valid values are the following:

  • database - Export all the data from a specified database.

  • database.table table-name - Export a table of the snapshot. This format is valid only for RDS for MySQL, RDS for MariaDB, and Aurora MySQL.

  • database.schema schema-name - Export a database schema of the snapshot. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.

  • database.schema.table table-name - Export a table of the database schema. This format is valid only for RDS for PostgreSQL and Aurora PostgreSQL.