Runs a batch SQL statement over an array of data.
See https://paws-r.github.io/docs/rdsdataservice/batch_execute_statement.html for full documentation.
rdsdataservice_batch_execute_statement(
database = NULL,
parameterSets = NULL,
resourceArn,
schema = NULL,
secretArn,
sql,
transactionId = NULL
)The name of the database.
The parameter set for the batch operation.
The SQL statement is executed as many times as the number of parameter sets provided. To execute a SQL statement with no parameters, use one of the following options:
Specify one or more empty parameter sets.
Use the execute_statement
operation instead of the
batch_execute_statement
operation.
Array parameters are not supported.
[required] The Amazon Resource Name (ARN) of the Aurora Serverless DB cluster.
The name of the database schema.
[required] The ARN of the secret that enables access to the DB cluster. Enter the database user name and password for the credentials in the secret.
For information about creating the secret, see Create a database secret.
[required] The SQL statement to run. Don't include a semicolon (;) at the end of the SQL statement.
The identifier of a transaction that was started by using the
begin_transaction operation.
Specify the transaction ID of the transaction that you want to include
the SQL statement in.
If the SQL statement is not part of a transaction, don't set this parameter.