Learn R Programming

paws.database (version 0.2.0)

rdsdataservice_execute_sql: Runs one or more SQL statements

Description

Runs one or more SQL statements.

See https://paws-r.github.io/docs/rdsdataservice/execute_sql.html for full documentation.

Usage

rdsdataservice_execute_sql(
  awsSecretStoreArn,
  database = NULL,
  dbClusterOrInstanceArn,
  schema = NULL,
  sqlStatements
)

Arguments

awsSecretStoreArn

[required] The Amazon Resource Name (ARN) of the secret that enables access to the DB cluster. Enter the database user name and password for the credentials in the secret.

For information about creating the secret, see Create a database secret.

database

The name of the database.

dbClusterOrInstanceArn

[required] The ARN of the Aurora Serverless DB cluster.

schema

The name of the database schema.

sqlStatements

[required] One or more SQL statements to run on the DB cluster.

You can separate SQL statements from each other with a semicolon (;). Any valid SQL statement is permitted, including data definition, data manipulation, and commit statements.