From a datashare consumer account, associates a datashare with the account (AssociateEntireAccount) or the specified namespace (ConsumerArn). If you make this association, the consumer can consume the datashare.
See https://paws-r.github.io/docs/redshift/associate_data_share_consumer.html for full documentation.
redshift_associate_data_share_consumer(
DataShareArn,
AssociateEntireAccount = NULL,
ConsumerArn = NULL,
ConsumerRegion = NULL
)[required] The Amazon Resource Name (ARN) of the datashare that the consumer is to use with the account or the namespace.
A value that specifies whether the datashare is associated with the entire account.
The Amazon Resource Name (ARN) of the consumer that is associated with the datashare.
From a datashare consumer account, associates a datashare with all existing and future namespaces in the specified Amazon Web Services Region.