Learn R Programming

paws.database (version 0.2.0)

redshift_create_authentication_profile: Creates an authentication profile with the specified parameters

Description

Creates an authentication profile with the specified parameters.

See https://paws-r.github.io/docs/redshift/create_authentication_profile.html for full documentation.

Usage

redshift_create_authentication_profile(
  AuthenticationProfileName,
  AuthenticationProfileContent
)

Arguments

AuthenticationProfileName

[required] The name of the authentication profile to be created.

AuthenticationProfileContent

[required] The content of the authentication profile in JSON format. The maximum length of the JSON string is determined by a quota for your account.