redshift_create_redshift_idc_application: Creates an Amazon Redshift application for use with IAM...

View source: R/redshift_operations.R

redshift_create_redshift_idc_applicationR Documentation

Creates an Amazon Redshift application for use with IAM Identity Center

Description

Creates an Amazon Redshift application for use with IAM Identity Center.

See https://www.paws-r-sdk.com/docs/redshift_create_redshift_idc_application/ for full documentation.

Usage

redshift_create_redshift_idc_application(
  IdcInstanceArn,
  RedshiftIdcApplicationName,
  IdentityNamespace = NULL,
  IdcDisplayName,
  IamRoleArn,
  AuthorizedTokenIssuerList = NULL,
  ServiceIntegrations = NULL,
  ApplicationType = NULL,
  Tags = NULL,
  SsoTagKeys = NULL
)

Arguments

IdcInstanceArn

[required] The Amazon resource name (ARN) of the IAM Identity Center instance where Amazon Redshift creates a new managed application.

RedshiftIdcApplicationName

[required] The name of the Redshift application in IAM Identity Center.

IdentityNamespace

The namespace for the Amazon Redshift IAM Identity Center application instance. It determines which managed application verifies the connection token.

IdcDisplayName

[required] The display name for the Amazon Redshift IAM Identity Center application instance. It appears in the console.

IamRoleArn

[required] The IAM role ARN for the Amazon Redshift IAM Identity Center application instance. It has the required permissions to be assumed and invoke the IDC Identity Center API.

AuthorizedTokenIssuerList

The token issuer list for the Amazon Redshift IAM Identity Center application instance.

ServiceIntegrations

A collection of service integrations for the Redshift IAM Identity Center application.

ApplicationType

The type of application being created. Valid values are None or Lakehouse. Use Lakehouse to enable Amazon Redshift federated permissions on cluster.

Tags

A list of tags.

SsoTagKeys

A list of tags keys that Redshift Identity Center applications copy to IAM Identity Center. For each input key, the tag corresponding to the key-value pair is propagated.


paws.database documentation built on June 1, 2026, 5:08 p.m.