Create a snapshot schedule that can be associated to a cluster and which overrides the default system backup schedule.
See https://paws-r.github.io/docs/redshift/create_snapshot_schedule.html for full documentation.
redshift_create_snapshot_schedule(
ScheduleDefinitions = NULL,
ScheduleIdentifier = NULL,
ScheduleDescription = NULL,
Tags = NULL,
DryRun = NULL,
NextInvocations = NULL
)The definition of the snapshot schedule. The definition is made up of schedule expressions, for example "cron(30 12 *)" or "rate(12 hours)".
A unique identifier for a snapshot schedule. Only alphanumeric characters are allowed for the identifier.
The description of the snapshot schedule.
An optional set of tags you can use to search for the schedule.