Learn R Programming

paws.database (version 0.2.0)

redshift_deauthorize_data_share: From a datashare producer account, removes authorization from the specified datashare

Description

From a datashare producer account, removes authorization from the specified datashare.

See https://paws-r.github.io/docs/redshift/deauthorize_data_share.html for full documentation.

Usage

redshift_deauthorize_data_share(DataShareArn, ConsumerIdentifier)

Arguments

DataShareArn

[required] The Amazon Resource Name (ARN) of the datashare to remove authorization from.

ConsumerIdentifier

[required] The identifier of the data consumer that is to have authorization removed from the datashare. This identifier is an Amazon Web Services account ID or a keyword, such as ADX.