Learn R Programming

paws.database (version 0.2.0)

redshift_delete_partner: Deletes a partner integration from a cluster

Description

Deletes a partner integration from a cluster. Data can still flow to the cluster until the integration is deleted at the partner's website.

See https://paws-r.github.io/docs/redshift/delete_partner.html for full documentation.

Usage

redshift_delete_partner(
  AccountId,
  ClusterIdentifier,
  DatabaseName,
  PartnerName
)

Arguments

AccountId

[required] The Amazon Web Services account ID that owns the cluster.

ClusterIdentifier

[required] The cluster identifier of the cluster that receives data from the partner.

DatabaseName

[required] The name of the database that receives data from the partner.

PartnerName

[required] The name of the partner that is authorized to send data.