Deletes a tag or tags from a resource. You must provide the ARN of the resource from which you want to delete the tag or tags.
redshift_delete_tags(ResourceName, TagKeys)[required] The Amazon Resource Name (ARN) from which you want to remove the tag or
tags. For example, arn:aws:redshift:us-east-1:123456789:cluster:t1.
[required] The tag key that you want to delete.
svc$delete_tags(
ResourceName = "string",
TagKeys = list(
"string"
)
)