redshift_deregister_namespace: Deregisters a cluster or serverless namespace from the Amazon...

View source: R/redshift_operations.R

redshift_deregister_namespaceR Documentation

Deregisters a cluster or serverless namespace from the Amazon Web Services Glue Data Catalog

Description

Deregisters a cluster or serverless namespace from the Amazon Web Services Glue Data Catalog.

See https://www.paws-r-sdk.com/docs/redshift_deregister_namespace/ for full documentation.

Usage

redshift_deregister_namespace(NamespaceIdentifier, ConsumerIdentifiers)

Arguments

NamespaceIdentifier

[required] The unique identifier of the cluster or serverless namespace that you want to deregister.

ConsumerIdentifiers

[required] An array containing the ID of the consumer account that you want to deregister the cluster or serverless namespace from.


paws.database documentation built on June 1, 2026, 5:08 p.m.