Learn R Programming

paws.database (version 0.2.0)

redshift_describe_account_attributes: Returns a list of attributes attached to an account

Description

Returns a list of attributes attached to an account

See https://paws-r.github.io/docs/redshift/describe_account_attributes.html for full documentation.

Usage

redshift_describe_account_attributes(AttributeNames = NULL)

Arguments

AttributeNames

A list of attribute names.