View source: R/redshift_operations.R
| redshift_describe_cluster_subnet_groups | R Documentation |
Returns one or more cluster subnet group objects, which contain metadata about your cluster subnet groups. By default, this operation returns information about all cluster subnet groups that are defined in your Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/redshift_describe_cluster_subnet_groups/ for full documentation.
redshift_describe_cluster_subnet_groups(
ClusterSubnetGroupName = NULL,
MaxRecords = NULL,
Marker = NULL,
TagKeys = NULL,
TagValues = NULL
)
ClusterSubnetGroupName |
The name of the cluster subnet group for which information is requested. |
MaxRecords |
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified Default: Constraints: minimum 20, maximum 100. |
Marker |
An optional parameter that specifies the starting point to return a set of response records. When the results of a |
TagKeys |
A tag key or keys for which you want to return all matching cluster subnet groups that are associated with the specified key or keys. For example, suppose that you have subnet groups that are tagged with keys called |
TagValues |
A tag value or values for which you want to return all matching cluster subnet groups that are associated with the specified tag value or values. For example, suppose that you have subnet groups that are tagged with values called |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.