Describes an endpoint authorization.
See https://paws-r.github.io/docs/redshift/describe_endpoint_authorization.html for full documentation.
redshift_describe_endpoint_authorization(
ClusterIdentifier = NULL,
Account = NULL,
Grantee = NULL,
MaxRecords = NULL,
Marker = NULL
)The cluster identifier of the cluster to access.
The AAmazon Web Services account ID of either the cluster owner
(grantor) or grantee. If Grantee parameter is true, then the Account
value is of the grantor.
Indicates whether to check authorization from a grantor or grantee point of view. If true, Amazon Redshift returns endpoint authorizations that you've been granted. If false (default), checks authorization from a grantor point of view.
The maximum number of records to include in the response. If more
records exist than the specified MaxRecords value, a pagination token
called a Marker is included in the response so that the remaining
results can be retrieved.
An optional pagination token provided by a previous
describe_endpoint_authorization
request. If this parameter is specified, the response includes only
records beyond the marker, up to the value specified by the MaxRecords
parameter.