Displays a list of event categories for all event source types, or for a specified source type. For a list of the event categories and source types, go to Amazon Redshift Event Notifications.
See https://paws-r.github.io/docs/redshift/describe_event_categories.html for full documentation.
redshift_describe_event_categories(SourceType = NULL)The source type, such as cluster or parameter group, to which the described event categories apply.
Valid values: cluster, cluster-snapshot, cluster-parameter-group, cluster-security-group, and scheduled-action.