View source: R/redshift_operations.R
| redshift_describe_hsm_client_certificates | R Documentation |
Returns information about the specified HSM client certificate. If no certificate ID is specified, returns information about all the HSM certificates owned by your Amazon Web Services account.
See https://www.paws-r-sdk.com/docs/redshift_describe_hsm_client_certificates/ for full documentation.
redshift_describe_hsm_client_certificates(
HsmClientCertificateIdentifier = NULL,
MaxRecords = NULL,
Marker = NULL,
TagKeys = NULL,
TagValues = NULL
)
HsmClientCertificateIdentifier |
The identifier of a specific HSM client certificate for which you want information. If no identifier is specified, information is returned for all HSM client certificates owned by your Amazon Web Services account. |
MaxRecords |
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified Default: Constraints: minimum 20, maximum 100. |
Marker |
An optional parameter that specifies the starting point to return a set of response records. When the results of a |
TagKeys |
A tag key or keys for which you want to return all matching HSM client certificates that are associated with the specified key or keys. For example, suppose that you have HSM client certificates that are tagged with keys called |
TagValues |
A tag value or values for which you want to return all matching HSM client certificates that are associated with the specified tag value or values. For example, suppose that you have HSM client certificates that are tagged with values called |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.