View source: R/redshift_operations.R
| redshift_describe_integrations | R Documentation |
Describes one or more zero-ETL or S3 event integrations with Amazon Redshift.
See https://www.paws-r-sdk.com/docs/redshift_describe_integrations/ for full documentation.
redshift_describe_integrations(
IntegrationArn = NULL,
MaxRecords = NULL,
Marker = NULL,
Filters = NULL
)
IntegrationArn |
The unique identifier of the integration. |
MaxRecords |
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified Default: Constraints: minimum 20, maximum 100. |
Marker |
An optional pagination token provided by a previous |
Filters |
A filter that specifies one or more resources to return. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.