Describes whether information, such as queries and connection attempts, is being logged for the specified Amazon Redshift cluster.
See https://paws-r.github.io/docs/redshift/describe_logging_status.html for full documentation.
redshift_describe_logging_status(ClusterIdentifier)[required] The identifier of the cluster from which to get the logging status.
Example: examplecluster