Returns information about the last resize operation for the specified cluster. If no resize operation has ever been initiated for the specified cluster, a HTTP 404 error is returned. If a resize operation was initiated and completed, the status of the resize remains as SUCCEEDED until the next resize.
See https://paws-r.github.io/docs/redshift/describe_resize.html for full documentation.
redshift_describe_resize(ClusterIdentifier)[required] The unique identifier of a cluster whose resize progress you are requesting. This parameter is case-sensitive.
By default, resize operations for all clusters defined for an Amazon Web Services account are returned.