Stops logging information, such as queries and connection attempts, for the specified Amazon Redshift cluster.
See https://paws-r.github.io/docs/redshift/disable_logging.html for full documentation.
redshift_disable_logging(ClusterIdentifier)[required] The identifier of the cluster on which logging is to be stopped.
Example: examplecluster