Learn R Programming

paws.database (version 0.2.0)

redshift_disable_snapshot_copy: Disables the automatic copying of snapshots from one region to another region for a specified cluster

Description

Disables the automatic copying of snapshots from one region to another region for a specified cluster.

See https://paws-r.github.io/docs/redshift/disable_snapshot_copy.html for full documentation.

Usage

redshift_disable_snapshot_copy(ClusterIdentifier)

Arguments

ClusterIdentifier

[required] The unique identifier of the source cluster that you want to disable copying of snapshots to a destination region.

Constraints: Must be the valid name of an existing cluster that has cross-region snapshot copy enabled.