redshift_failover_primary_compute: Fails over the primary compute unit of the specified Multi-AZ...

View source: R/redshift_operations.R

redshift_failover_primary_computeR Documentation

Fails over the primary compute unit of the specified Multi-AZ cluster to another Availability Zone

Description

Fails over the primary compute unit of the specified Multi-AZ cluster to another Availability Zone.

See https://www.paws-r-sdk.com/docs/redshift_failover_primary_compute/ for full documentation.

Usage

redshift_failover_primary_compute(ClusterIdentifier)

Arguments

ClusterIdentifier

[required] The unique identifier of the cluster for which the primary compute unit will be failed over to another Availability Zone.


paws.database documentation built on June 1, 2026, 5:08 p.m.