redshift_get_identity_center_auth_token: Generates an encrypted authentication token that propagates...

View source: R/redshift_operations.R

redshift_get_identity_center_auth_tokenR Documentation

Generates an encrypted authentication token that propagates the caller's Amazon Web Services IAM Identity Center identity to Amazon Redshift clusters

Description

Generates an encrypted authentication token that propagates the caller's Amazon Web Services IAM Identity Center identity to Amazon Redshift clusters. This API extracts the Amazon Web Services IAM Identity Center identity from enhanced credentials and creates a secure token that Amazon Redshift drivers can use for authentication.

See https://www.paws-r-sdk.com/docs/redshift_get_identity_center_auth_token/ for full documentation.

Usage

redshift_get_identity_center_auth_token(ClusterIds)

Arguments

ClusterIds

[required] A list of cluster identifiers that the generated token can be used with. The token will be scoped to only allow authentication to the specified clusters.

Constraints:

  • ClusterIds must contain at least 1 cluster identifier.

  • ClusterIds can hold a maximum of 20 cluster identifiers.

  • Cluster identifiers must be 1 to 63 characters in length.

  • The characters accepted for cluster identifiers are the following:

    • Alphanumeric characters

    • Hyphens

  • Cluster identifiers must start with a letter.

  • Cluster identifiers can't end with a hyphen or contain two consecutive hyphens.


paws.database documentation built on June 1, 2026, 5:08 p.m.