Modifies an authentication profile.
See https://paws-r.github.io/docs/redshift/modify_authentication_profile.html for full documentation.
redshift_modify_authentication_profile(
AuthenticationProfileName,
AuthenticationProfileContent
)[required] The name of the authentication profile to replace.
[required] The new content of the authentication profile in JSON format. The maximum length of the JSON string is determined by a quota for your account.