Learn R Programming

paws.database (version 0.2.0)

redshift_modify_cluster_db_revision: Modifies the database revision of a cluster

Description

Modifies the database revision of a cluster. The database revision is a unique revision of the database running in a cluster.

See https://paws-r.github.io/docs/redshift/modify_cluster_db_revision.html for full documentation.

Usage

redshift_modify_cluster_db_revision(ClusterIdentifier, RevisionTarget)

Arguments

ClusterIdentifier

[required] The unique identifier of a cluster whose database revision you want to modify.

Example: examplecluster

RevisionTarget

[required] The identifier of the database revision. You can retrieve this value from the response to the describe_cluster_db_revisions request.