Learn R Programming

paws.database (version 0.2.0)

redshift_modify_cluster_snapshot_schedule: Modifies a snapshot schedule for a cluster

Description

Modifies a snapshot schedule for a cluster.

See https://paws-r.github.io/docs/redshift/modify_cluster_snapshot_schedule.html for full documentation.

Usage

redshift_modify_cluster_snapshot_schedule(
  ClusterIdentifier,
  ScheduleIdentifier = NULL,
  DisassociateSchedule = NULL
)

Arguments

ClusterIdentifier

[required] A unique identifier for the cluster whose snapshot schedule you want to modify.

ScheduleIdentifier

A unique alphanumeric identifier for the schedule that you want to associate with the cluster.

DisassociateSchedule

A boolean to indicate whether to remove the assoiciation between the cluster and the schedule.