Modifies a cluster subnet group to include the specified list of VPC subnets. The operation replaces the existing list of subnets with the new list of subnets.
See https://paws-r.github.io/docs/redshift/modify_cluster_subnet_group.html for full documentation.
redshift_modify_cluster_subnet_group(
ClusterSubnetGroupName,
Description = NULL,
SubnetIds
)[required] The name of the subnet group to be modified.
A text description of the subnet group to be modified.
[required] An array of VPC subnet IDs. A maximum of 20 subnets can be modified in a single request.