View source: R/redshift_operations.R
| redshift_modify_lakehouse_configuration | R Documentation |
Modifies the lakehouse configuration for a cluster. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
See https://www.paws-r-sdk.com/docs/redshift_modify_lakehouse_configuration/ for full documentation.
redshift_modify_lakehouse_configuration(
ClusterIdentifier,
LakehouseRegistration = NULL,
CatalogName = NULL,
LakehouseIdcRegistration = NULL,
LakehouseIdcApplicationArn = NULL,
DryRun = NULL
)
ClusterIdentifier |
[required] The unique identifier of the cluster whose lakehouse configuration you want to modify. |
LakehouseRegistration |
Specifies whether to register or deregister the cluster with Amazon Redshift federated permissions. Valid values are |
CatalogName |
The name of the Glue data catalog that will be associated with the cluster enabled with Amazon Redshift federated permissions. Constraints:
Pattern: Example: |
LakehouseIdcRegistration |
Modifies the Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions. Valid values are |
LakehouseIdcApplicationArn |
The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a cluster enabled with Amazon Redshift federated permissions. |
DryRun |
A boolean value that, if |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.