Modifies a snapshot schedule. Any schedule associated with a cluster is modified asynchronously.
See https://paws-r.github.io/docs/redshift/modify_snapshot_schedule.html for full documentation.
redshift_modify_snapshot_schedule(ScheduleIdentifier, ScheduleDefinitions)[required] A unique alphanumeric identifier of the schedule to modify.
[required] An updated list of schedule definitions. A schedule definition is made up of schedule expressions, for example, "cron(30 12 *)" or "rate(12 hours)".