Allows you to purchase reserved nodes. Amazon Redshift offers a predefined set of reserved node offerings. You can purchase one or more of the offerings. You can call the describe_reserved_node_offerings API to obtain the available reserved node offerings. You can call this API by providing a specific reserved node offering and the number of nodes you want to reserve.
See https://paws-r.github.io/docs/redshift/purchase_reserved_node_offering.html for full documentation.
redshift_purchase_reserved_node_offering(
ReservedNodeOfferingId,
NodeCount = NULL
)[required] The unique identifier of the reserved node offering you want to purchase.
The number of reserved nodes that you want to purchase.
Default: 1