redshift_register_namespace: Registers a cluster or serverless namespace to the Amazon Web...

View source: R/redshift_operations.R

redshift_register_namespaceR Documentation

Registers a cluster or serverless namespace to the Amazon Web Services Glue Data Catalog

Description

Registers a cluster or serverless namespace to the Amazon Web Services Glue Data Catalog.

See https://www.paws-r-sdk.com/docs/redshift_register_namespace/ for full documentation.

Usage

redshift_register_namespace(NamespaceIdentifier, ConsumerIdentifiers)

Arguments

NamespaceIdentifier

[required] The unique identifier of the cluster or serverless namespace that you want to register.

ConsumerIdentifiers

[required] An array containing the ID of the consumer account that you want to register the namespace to.


paws.database documentation built on June 1, 2026, 5:08 p.m.