Learn R Programming

paws.database (version 0.2.0)

redshift_reject_data_share: From a datashare consumer account, rejects the specified datashare

Description

From a datashare consumer account, rejects the specified datashare.

See https://paws-r.github.io/docs/redshift/reject_data_share.html for full documentation.

Usage

redshift_reject_data_share(DataShareArn)

Arguments

DataShareArn

[required] The Amazon Resource Name (ARN) of the datashare to reject.