Learn R Programming

paws.database (version 0.2.0)

redshift_rotate_encryption_key: Rotates the encryption keys for a cluster

Description

Rotates the encryption keys for a cluster.

See https://paws-r.github.io/docs/redshift/rotate_encryption_key.html for full documentation.

Usage

redshift_rotate_encryption_key(ClusterIdentifier)

Arguments

ClusterIdentifier

[required] The unique identifier of the cluster that you want to rotate the encryption keys for.

Constraints: Must be the name of valid cluster that has encryption enabled.