Updates the status of a partner integration.
See https://paws-r.github.io/docs/redshift/update_partner_status.html for full documentation.
redshift_update_partner_status(
AccountId,
ClusterIdentifier,
DatabaseName,
PartnerName,
Status,
StatusMessage = NULL
)[required] The Amazon Web Services account ID that owns the cluster.
[required] The cluster identifier of the cluster whose partner integration status is being updated.
[required] The name of the database whose partner integration status is being updated.
[required] The name of the partner whose integration status is being updated.
[required] The value of the updated status.
The status message provided by the partner.