redshiftdataapiservice_batch_execute_statement: Runs one or more SQL statements, which can be data...

View source: R/redshiftdataapiservice_operations.R

redshiftdataapiservice_batch_execute_statementR Documentation

Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL)

Description

Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL). Depending on the authorization method, use one of the following combinations of request parameters:

See https://www.paws-r-sdk.com/docs/redshiftdataapiservice_batch_execute_statement/ for full documentation.

Usage

redshiftdataapiservice_batch_execute_statement(
  Sqls,
  ClusterIdentifier = NULL,
  SecretArn = NULL,
  DbUser = NULL,
  Database = NULL,
  WithEvent = NULL,
  StatementName = NULL,
  Parameters = NULL,
  WorkgroupName = NULL,
  ClientToken = NULL,
  ResultFormat = NULL,
  SessionKeepAliveSeconds = NULL,
  SessionId = NULL
)

Arguments

Sqls

[required] One or more SQL statements to run. The SQL statements are run as a single transaction. They run serially in the order of the array. Subsequent SQL statements don't start until the previous statement in the array completes. If any SQL statement fails, then because they are run as one transaction, all work is rolled back.

ClusterIdentifier

The cluster identifier. This parameter is required when connecting to a cluster and authenticating using either Secrets Manager or temporary credentials.

SecretArn

The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager.

DbUser

The database user name. This parameter is required when connecting to a cluster as a database user and authenticating using temporary credentials.

Database

The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials.

WithEvent

A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statements run.

StatementName

The name of the SQL statements. You can name the SQL statements when you create them to identify the query.

Parameters

The parameters for the SQL statements. The parameters are shared across all SQL statements in the batch.

WorkgroupName

The serverless workgroup name or Amazon Resource Name (ARN). This parameter is required when connecting to a serverless workgroup and authenticating using either Secrets Manager or temporary credentials.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

ResultFormat

The data format of the result of the SQL statement. If no format is specified, the default is JSON.

SessionKeepAliveSeconds

The number of seconds to keep the session alive after the query finishes. The maximum time a session can keep alive is 24 hours. After 24 hours, the session is forced closed and the query is terminated.

SessionId

The session identifier of the query.


paws.database documentation built on June 1, 2026, 5:08 p.m.