redshiftdataapiservice_execute_statement: Runs an SQL statement, which can be data manipulation...

View source: R/redshiftdataapiservice_operations.R

redshiftdataapiservice_execute_statementR Documentation

Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL)

Description

Runs an SQL statement, which can be data manipulation language (DML) or data definition language (DDL). This statement must be a single SQL statement. Depending on the authorization method, use one of the following combinations of request parameters:

See https://www.paws-r-sdk.com/docs/redshiftdataapiservice_execute_statement/ for full documentation.

Usage

redshiftdataapiservice_execute_statement(
  Sql,
  ClusterIdentifier = NULL,
  SecretArn = NULL,
  DbUser = NULL,
  Database = NULL,
  WithEvent = NULL,
  StatementName = NULL,
  Parameters = NULL,
  WorkgroupName = NULL,
  ClientToken = NULL,
  ResultFormat = NULL,
  SessionKeepAliveSeconds = NULL,
  SessionId = NULL
)

Arguments

Sql

[required] The SQL statement text to run.

ClusterIdentifier

The cluster identifier. This parameter is required when connecting to a cluster and authenticating using either Secrets Manager or temporary credentials.

SecretArn

The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager.

DbUser

The database user name. This parameter is required when connecting to a cluster as a database user and authenticating using temporary credentials.

Database

The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials.

WithEvent

A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statement runs.

StatementName

The name of the SQL statement. You can name the SQL statement when you create it to identify the query.

Parameters

The parameters for the SQL statement.

WorkgroupName

The serverless workgroup name or Amazon Resource Name (ARN). This parameter is required when connecting to a serverless workgroup and authenticating using either Secrets Manager or temporary credentials.

ClientToken

A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.

ResultFormat

The data format of the result of the SQL statement. If no format is specified, the default is JSON.

SessionKeepAliveSeconds

The number of seconds to keep the session alive after the query finishes. The maximum time a session can keep alive is 24 hours. After 24 hours, the session is forced closed and the query is terminated.

SessionId

The session identifier of the query.


paws.database documentation built on June 1, 2026, 5:08 p.m.