View source: R/redshiftdataapiservice_operations.R
| redshiftdataapiservice_list_statements | R Documentation |
List of SQL statements. By default, only finished statements are shown. A token is returned to page through the statement list.
See https://www.paws-r-sdk.com/docs/redshiftdataapiservice_list_statements/ for full documentation.
redshiftdataapiservice_list_statements(
NextToken = NULL,
MaxResults = NULL,
StatementName = NULL,
Status = NULL,
RoleLevel = NULL,
Database = NULL,
ClusterIdentifier = NULL,
WorkgroupName = NULL
)
NextToken |
A value that indicates the starting point for the next set of response records in a subsequent request. If a value is returned in a response, you can retrieve the next set of records by providing this returned NextToken value in the next NextToken parameter and retrying the command. If the NextToken field is empty, all response records have been retrieved for the request. |
MaxResults |
The maximum number of SQL statements to return in the response. If more SQL statements exist than fit in one response, then |
StatementName |
The name of the SQL statement specified as input to |
Status |
The status of the SQL statement to list. Status values are defined as follows:
|
RoleLevel |
A value that filters which statements to return in the response. If true, all statements run by the caller's IAM role are returned. If false, only statements run by the caller's IAM role in the current IAM session are returned. The default is true. |
Database |
The name of the database when listing statements run against a |
ClusterIdentifier |
The cluster identifier. Only statements that ran on this cluster are returned. When providing |
WorkgroupName |
The serverless workgroup name or Amazon Resource Name (ARN). Only statements that ran on this workgroup are returned. When providing |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.