redshiftserverless_create_custom_domain_association: Creates a custom domain association for Amazon Redshift...

View source: R/redshiftserverless_operations.R

redshiftserverless_create_custom_domain_associationR Documentation

Creates a custom domain association for Amazon Redshift Serverless

Description

Creates a custom domain association for Amazon Redshift Serverless.

See https://www.paws-r-sdk.com/docs/redshiftserverless_create_custom_domain_association/ for full documentation.

Usage

redshiftserverless_create_custom_domain_association(
  customDomainCertificateArn,
  customDomainName,
  workgroupName
)

Arguments

customDomainCertificateArn

[required] The custom domain name’s certificate Amazon resource name (ARN).

customDomainName

[required] The custom domain name to associate with the workgroup.

workgroupName

[required] The name of the workgroup associated with the database.


paws.database documentation built on June 1, 2026, 5:08 p.m.