Creates an Amazon Redshift Serverless managed VPC endpoint.
See https://paws-r.github.io/docs/redshiftserverless/create_endpoint_access.html for full documentation.
redshiftserverless_create_endpoint_access(
endpointName,
subnetIds,
vpcSecurityGroupIds = NULL,
workgroupName
)[required] The name of the VPC endpoint. An endpoint name must contain 1-30 characters. Valid characters are A-Z, a-z, 0-9, and hyphen(-). The first character must be a letter. The name can't contain two consecutive hyphens or end with a hyphen.
[required] The unique identifers of subnets from which Amazon Redshift Serverless chooses one to deploy a VPC endpoint.
The unique identifiers of the security group that defines the ports, protocols, and sources for inbound traffic that you are authorizing into your endpoint.
[required] The name of the workgroup to associate with the VPC endpoint.