Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_create_snapshot: Creates a snapshot of all databases in a namespace

Description

Creates a snapshot of all databases in a namespace. For more information about snapshots, see Working with snapshots and recovery points.

See https://paws-r.github.io/docs/redshiftserverless/create_snapshot.html for full documentation.

Usage

redshiftserverless_create_snapshot(
  namespaceName,
  retentionPeriod = NULL,
  snapshotName
)

Arguments

namespaceName

[required] The namespace to create a snapshot for.

retentionPeriod

How long to retain the created snapshot.

snapshotName

[required] The name of the snapshot.