Deletes a namespace from Amazon Redshift Serverless. Before you delete the namespace, you can create a final snapshot that has all of the data within the namespace.
See https://paws-r.github.io/docs/redshiftserverless/delete_namespace.html for full documentation.
redshiftserverless_delete_namespace(
finalSnapshotName = NULL,
finalSnapshotRetentionPeriod = NULL,
namespaceName
)The name of the snapshot to be created before the namespace is deleted.
How long to retain the final snapshot.
[required] The name of the namespace to delete.