Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_get_endpoint_access: Returns information, such as the name, about a VPC endpoint

Description

Returns information, such as the name, about a VPC endpoint.

See https://paws-r.github.io/docs/redshiftserverless/get_endpoint_access.html for full documentation.

Usage

redshiftserverless_get_endpoint_access(endpointName)

Arguments

endpointName

[required] The name of the VPC endpoint to return information for.