View source: R/redshiftserverless_operations.R
| redshiftserverless_get_identity_center_auth_token | R Documentation |
Returns an Identity Center authentication token for accessing Amazon Redshift Serverless workgroups.
See https://www.paws-r-sdk.com/docs/redshiftserverless_get_identity_center_auth_token/ for full documentation.
redshiftserverless_get_identity_center_auth_token(workgroupNames)
workgroupNames |
[required] A list of workgroup names for which to generate the Identity Center authentication token. Constraints:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.