powered by
Returns information about a namespace in Amazon Redshift Serverless.
See https://paws-r.github.io/docs/redshiftserverless/get_namespace.html for full documentation.
redshiftserverless_get_namespace(namespaceName)
[required] The name of the namespace to retrieve information for.