View source: R/redshiftserverless_operations.R
| redshiftserverless_get_reservation | R Documentation |
Gets an Amazon Redshift Serverless reservation. A reservation gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
See https://www.paws-r-sdk.com/docs/redshiftserverless_get_reservation/ for full documentation.
redshiftserverless_get_reservation(reservationId)
reservationId |
[required] The ID of the reservation to retrieve. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.