View source: R/redshiftserverless_operations.R
| redshiftserverless_get_track | R Documentation |
Get the Redshift Serverless version for a specified track.
See https://www.paws-r-sdk.com/docs/redshiftserverless_get_track/ for full documentation.
redshiftserverless_get_track(trackName)
trackName |
[required] The name of the track of which its version is fetched. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.