Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_list_endpoint_access: Returns an array of EndpointAccess objects and relevant information

Description

Returns an array of EndpointAccess objects and relevant information.

See https://paws-r.github.io/docs/redshiftserverless/list_endpoint_access.html for full documentation.

Usage

redshiftserverless_list_endpoint_access(
  maxResults = NULL,
  nextToken = NULL,
  vpcId = NULL,
  workgroupName = NULL
)

Arguments

maxResults

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

nextToken

If your initial list_endpoint_access operation returns a nextToken, you can include the returned nextToken in subsequent list_endpoint_access operations, which returns results in the next page.

vpcId

The unique identifier of the virtual private cloud with access to Amazon Redshift Serverless.

workgroupName

The name of the workgroup associated with the VPC endpoint to return.