View source: R/redshiftserverless_operations.R
| redshiftserverless_list_managed_workgroups | R Documentation |
Returns information about a list of specified managed workgroups in your account.
See https://www.paws-r-sdk.com/docs/redshiftserverless_list_managed_workgroups/ for full documentation.
redshiftserverless_list_managed_workgroups(
maxResults = NULL,
nextToken = NULL,
sourceArn = NULL
)
maxResults |
An optional parameter that specifies the maximum number of results to return. You can use nextToken to display the next page of results. |
nextToken |
If your initial ListManagedWorkgroups operation returns a nextToken, you can include the returned nextToken in following ListManagedWorkgroups operations, which returns results in the next page. |
sourceArn |
The Amazon Resource Name (ARN) for the managed workgroup in the Glue Data Catalog. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.