Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_list_namespaces: Returns information about a list of specified namespaces

Description

Returns information about a list of specified namespaces.

See https://paws-r.github.io/docs/redshiftserverless/list_namespaces.html for full documentation.

Usage

redshiftserverless_list_namespaces(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

nextToken

If your initial list_namespaces operation returns a nextToken, you can include the returned nextToken in subsequent list_namespaces operations, which returns results in the next page.