Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_list_recovery_points: Returns an array of recovery points

Description

Returns an array of recovery points.

See https://paws-r.github.io/docs/redshiftserverless/list_recovery_points.html for full documentation.

Usage

redshiftserverless_list_recovery_points(
  endTime = NULL,
  maxResults = NULL,
  namespaceName = NULL,
  nextToken = NULL,
  startTime = NULL
)

Arguments

endTime

The time when creation of the recovery point finished.

maxResults

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

namespaceName

The name of the namespace to list recovery points for.

nextToken

If your initial list_recovery_points operation returns a nextToken, you can include the returned nextToken in subsequent list_recovery_points operations, which returns results in the next page.

startTime

The time when the recovery point's creation was initiated.