View source: R/redshiftserverless_operations.R
| redshiftserverless_list_reservations | R Documentation |
Returns a list of Reservation objects.
See https://www.paws-r-sdk.com/docs/redshiftserverless_list_reservations/ for full documentation.
redshiftserverless_list_reservations(maxResults = NULL, nextToken = NULL)
maxResults |
The maximum number of items to return for this call. The call also returns a token that you can specify in a subsequent call to get the next set of results. |
nextToken |
The token for the next set of items to return. (You received this token from a previous call.) |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.