Returns a list of snapshot copy configurations.
See https://www.paws-r-sdk.com/docs/redshiftserverless_list_snapshot_copy_configurations/ for full documentation.
redshiftserverless_list_snapshot_copy_configurations(
maxResults = NULL,
namespaceName = NULL,
nextToken = NULL
)An optional parameter that specifies the maximum number of results to
return. You can use nextToken to display the next page of results.
The namespace from which to list all snapshot copy configurations.
If nextToken is returned, there are more results available. The value
of nextToken is a unique pagination token for each page. Make the call
again using the returned token to retrieve the next page.