redshiftserverless_list_tracks: List the Amazon Redshift Serverless versions

View source: R/redshiftserverless_operations.R

redshiftserverless_list_tracksR Documentation

List the Amazon Redshift Serverless versions

Description

List the Amazon Redshift Serverless versions.

See https://www.paws-r-sdk.com/docs/redshiftserverless_list_tracks/ for full documentation.

Usage

redshiftserverless_list_tracks(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value.

nextToken

If your initial ListTracksRequest operation returns a nextToken, you can include the returned nextToken in following ListTracksRequest operations, which returns results in the next page.


paws.database documentation built on June 1, 2026, 5:08 p.m.