Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_list_workgroups: Returns information about a list of specified workgroups

Description

Returns information about a list of specified workgroups.

See https://paws-r.github.io/docs/redshiftserverless/list_workgroups.html for full documentation.

Usage

redshiftserverless_list_workgroups(maxResults = NULL, nextToken = NULL)

Arguments

maxResults

An optional parameter that specifies the maximum number of results to return. You can use nextToken to get the next page of results.

nextToken

If your initial ListWorkgroups operation returns a nextToken, you can include the returned nextToken in subsequent ListNamespaces operations, which returns results in the next page.