Restore the data from a recovery point.
See https://paws-r.github.io/docs/redshiftserverless/restore_from_recovery_point.html for full documentation.
redshiftserverless_restore_from_recovery_point(
namespaceName,
recoveryPointId,
workgroupName
)[required] The name of the namespace to restore data into.
[required] The unique identifier of the recovery point to restore from.
[required] The name of the workgroup used to restore data.