Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_restore_from_snapshot: Restores a namespace from a snapshot

Description

Restores a namespace from a snapshot.

See https://paws-r.github.io/docs/redshiftserverless/restore_from_snapshot.html for full documentation.

Usage

redshiftserverless_restore_from_snapshot(
  namespaceName,
  ownerAccount = NULL,
  snapshotArn = NULL,
  snapshotName = NULL,
  workgroupName
)

Arguments

namespaceName

[required] The name of the namespace to restore the snapshot to.

ownerAccount

The Amazon Web Services account that owns the snapshot.

snapshotArn

The Amazon Resource Name (ARN) of the snapshot to restore from.

snapshotName

The name of the snapshot to restore from.

workgroupName

[required] The name of the workgroup used to restore the snapshot.