Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_untag_resource: Removes a tag or set of tags from a resource

Description

Removes a tag or set of tags from a resource.

See https://paws-r.github.io/docs/redshiftserverless/untag_resource.html for full documentation.

Usage

redshiftserverless_untag_resource(resourceArn, tagKeys)

Arguments

resourceArn

[required] The Amazon Resource Name (ARN) of the resource to remove tags from.

tagKeys

[required] The tag or set of tags to remove from the resource.