redshiftserverless_update_lakehouse_configuration: Modifies the lakehouse configuration for a namespace

View source: R/redshiftserverless_operations.R

redshiftserverless_update_lakehouse_configurationR Documentation

Modifies the lakehouse configuration for a namespace

Description

Modifies the lakehouse configuration for a namespace. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.

See https://www.paws-r-sdk.com/docs/redshiftserverless_update_lakehouse_configuration/ for full documentation.

Usage

redshiftserverless_update_lakehouse_configuration(
  catalogName = NULL,
  dryRun = NULL,
  lakehouseIdcApplicationArn = NULL,
  lakehouseIdcRegistration = NULL,
  lakehouseRegistration = NULL,
  namespaceName
)

Arguments

catalogName

The name of the Glue Data Catalog that will be associated with the namespace enabled with Amazon Redshift federated permissions.

Pattern: ⁠^[a-z0-9_-]*[a-z]+[a-z0-9_-]*$⁠

dryRun

A boolean value that, if true, validates the request without actually updating the lakehouse configuration. Use this to check for errors before making changes.

lakehouseIdcApplicationArn

The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a namespace enabled with Amazon Redshift federated permissions.

lakehouseIdcRegistration

Modifies the Amazon Web Services IAM Identity Center trusted identity propagation on a namespace enabled with Amazon Redshift federated permissions. Valid values are Associate or Disassociate.

lakehouseRegistration

Specifies whether to register or deregister the namespace with Amazon Redshift federated permissions. Valid values are Register or Deregister.

namespaceName

[required] The name of the namespace whose lakehouse configuration you want to modify.


paws.database documentation built on June 1, 2026, 5:08 p.m.