Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_update_namespace: Updates a namespace with the specified settings

Description

Updates a namespace with the specified settings.

See https://paws-r.github.io/docs/redshiftserverless/update_namespace.html for full documentation.

Usage

redshiftserverless_update_namespace(
  adminUserPassword = NULL,
  adminUsername = NULL,
  defaultIamRoleArn = NULL,
  iamRoles = NULL,
  kmsKeyId = NULL,
  logExports = NULL,
  namespaceName
)

Arguments

adminUserPassword

The password of the administrator for the first database created in the namespace.

adminUsername

The username of the administrator for the first database created in the namespace.

defaultIamRoleArn

The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.

iamRoles

A list of IAM roles to associate with the namespace.

kmsKeyId

The ID of the Amazon Web Services Key Management Service key used to encrypt your data.

logExports

The types of logs the namespace can export. The export types are userlog, connectionlog, and useractivitylog.

namespaceName

[required] The name of the namespace.