Learn R Programming

paws.database (version 0.2.0)

redshiftserverless_update_usage_limit: Update a usage limit in Amazon Redshift Serverless

Description

Update a usage limit in Amazon Redshift Serverless. You can't update the usage type or period of a usage limit.

See https://paws-r.github.io/docs/redshiftserverless/update_usage_limit.html for full documentation.

Usage

redshiftserverless_update_usage_limit(
  amount = NULL,
  breachAction = NULL,
  usageLimitId
)

Arguments

amount

The new limit amount. For more information about this parameter.

breachAction

The new action that Amazon Redshift Serverless takes when the limit is reached.

usageLimitId

[required] The identifier of the usage limit to update.