Performs multiple DeleteAttributes operations in a single call, which reduces round trips and latencies. This enables Amazon SimpleDB to optimize requests, which generally yields better throughput.
See https://paws-r.github.io/docs/simpledb/batch_delete_attributes.html for full documentation.
simpledb_batch_delete_attributes(DomainName, Items)[required] The name of the domain in which the attributes are being deleted.
[required] A list of items on which to perform the operation.