A synchronous operation that allows you to submit a query with parameters to be stored by Timestream for later running. Timestream only supports using this operation with the PrepareQueryRequest$ValidateOnly set to true.
See https://paws-r.github.io/docs/timestreamquery/prepare_query.html for full documentation.
timestreamquery_prepare_query(QueryString, ValidateOnly = NULL)[required] The Timestream query string that you want to use as a prepared
statement. Parameter names can be specified in the query string @
character followed by an identifier.
By setting this value to true, Timestream will only validate that the
query string is a valid Timestream query, and not store the prepared
query for later use.