View source: R/timestreamquery_operations.R
| timestreamquery_query | R Documentation |
query is a synchronous operation that enables you to run a query against your Amazon Timestream data.
See https://www.paws-r-sdk.com/docs/timestreamquery_query/ for full documentation.
timestreamquery_query(
QueryString,
ClientToken = NULL,
NextToken = NULL,
MaxRows = NULL,
QueryInsights = NULL
)
QueryString |
[required] The query to be run by Timestream. |
ClientToken |
Unique, case-sensitive string of up to 64 ASCII characters specified when a
|
NextToken |
A pagination token used to return a set of results. When the Note the following when using NextToken in a query:
|
MaxRows |
The total number of rows to be returned in the
Otherwise, the initial invocation of If the row size is large (e.g. a row has many columns), Timestream may return fewer rows to keep the response size from exceeding the 1 MB limit. If |
QueryInsights |
Encapsulates settings for enabling Enabling |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.