Associate a set of tags with a Timestream resource. You can then activate these user-defined tags so that they appear on the Billing and Cost Management console for cost allocation tracking.
See https://paws-r.github.io/docs/timestreamquery/tag_resource.html for full documentation.
timestreamquery_tag_resource(ResourceARN, Tags)[required] Identifies the Timestream resource to which tags should be added. This value is an Amazon Resource Name (ARN).
[required] The tags to be assigned to the Timestream resource.