Removes the association of tags from a Timestream query resource.
See https://paws-r.github.io/docs/timestreamquery/untag_resource.html for full documentation.
timestreamquery_untag_resource(ResourceARN, TagKeys)[required] The Timestream resource that the tags will be removed from. This value is an Amazon Resource Name (ARN).
[required] A list of tags keys. Existing tags of the resource whose keys are members of this list will be removed from the Timestream resource.