Deletes a given Timestream database. This is an irreversible operation. After a database is deleted, the time series data from its tables cannot be recovered.
See https://paws-r.github.io/docs/timestreamwrite/delete_database.html for full documentation.
timestreamwrite_delete_database(DatabaseName)[required] The name of the Timestream database to be deleted.