Learn R Programming

paws.database (version 0.2.0)

timestreamwrite_delete_table: Deletes a given Timestream table

Description

Deletes a given Timestream table. This is an irreversible operation. After a Timestream database table is deleted, the time series data stored in the table cannot be recovered.

See https://paws-r.github.io/docs/timestreamwrite/delete_table.html for full documentation.

Usage

timestreamwrite_delete_table(DatabaseName, TableName)

Arguments

DatabaseName

[required] The name of the database where the Timestream database is to be deleted.

TableName

[required] The name of the Timestream table to be deleted.