Returns information about the table, including the table name, database name, retention duration of the memory store and the magnetic store. Service quotas apply. See code sample for details.
See https://paws-r.github.io/docs/timestreamwrite/describe_table.html for full documentation.
timestreamwrite_describe_table(DatabaseName, TableName)[required] The name of the Timestream database.
[required] The name of the Timestream table.