Learn R Programming

paws.database (version 0.2.0)

timestreamwrite_list_databases: Returns a list of your Timestream databases

Description

Returns a list of your Timestream databases. Service quotas apply. See code sample for details.

See https://paws-r.github.io/docs/timestreamwrite/list_databases.html for full documentation.

Usage

timestreamwrite_list_databases(NextToken = NULL, MaxResults = NULL)

Arguments

NextToken

The pagination token. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.

MaxResults

The total number of items to return in the output. If the total number of items available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.