Learn R Programming

paws.database (version 0.2.0)

timestreamwrite_list_tables: A list of tables, along with the name, status and retention properties of each table

Description

A list of tables, along with the name, status and retention properties of each table. See code sample for details.

See https://paws-r.github.io/docs/timestreamwrite/list_tables.html for full documentation.

Usage

timestreamwrite_list_tables(
  DatabaseName = NULL,
  NextToken = NULL,
  MaxResults = NULL
)

Arguments

DatabaseName

The name of the Timestream database.

NextToken

The pagination token. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.

MaxResults

The total number of items to return in the output. If the total number of items available is more than the value specified, a NextToken is provided in the output. To resume pagination, provide the NextToken value as argument of a subsequent API invocation.