Learn R Programming

paws.database (version 0.2.0)

timestreamwrite_write_records: The WriteRecords operation enables you to write your time series data into Timestream

Description

The WriteRecords operation enables you to write your time series data into Timestream. You can specify a single data point or a batch of data points to be inserted into the system. Timestream offers you with a flexible schema that auto detects the column names and data types for your Timestream tables based on the dimension names and data types of the data points you specify when invoking writes into the database. Timestream support eventual consistency read semantics. This means that when you query data immediately after writing a batch of data into Timestream, the query results might not reflect the results of a recently completed write operation. The results may also include some stale data. If you repeat the query request after a short time, the results should return the latest data. Service quotas apply.

See https://paws-r.github.io/docs/timestreamwrite/write_records.html for full documentation.

Usage

timestreamwrite_write_records(
  DatabaseName,
  TableName,
  CommonAttributes = NULL,
  Records
)

Arguments

DatabaseName

[required] The name of the Timestream database.

TableName

[required] The name of the Timestream table.

CommonAttributes

A record containing the common measure, dimension, time, and version attributes shared across all the records in the request. The measure and dimension attributes specified will be merged with the measure and dimension attributes in the records object when the data is written into Timestream. Dimensions may not overlap, or a ValidationException will be thrown. In other words, a record must contain dimensions with unique names.

Records

[required] An array of records containing the unique measure, dimension, time, and version attributes for each time series data point.