Deletes a previously provisioned DAX cluster. DeleteCluster deletes all associated nodes, node endpoints and the DAX cluster itself. When you receive a successful response from this action, DAX immediately begins deleting the cluster; you cannot cancel or revert this action.
See https://paws-r.github.io/docs/dax/delete_cluster.html for full documentation.
dax_delete_cluster(ClusterName)[required] The name of the cluster to be deleted.