List all of the tags for a DAX cluster. You can call ListTags up to 10
times per second, per account.
dax_list_tags(ResourceName, NextToken)[required] The name of the DAX resource to which the tags belong.
An optional token returned from a prior request. Use this token for pagination of results from this action. If this parameter is specified, the response includes only results beyond the token.
svc$list_tags( ResourceName = "string", NextToken = "string" )