Detaches an Amazon DocumentDB secondary cluster from a global cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary in a different region.
See https://paws-r.github.io/docs/docdb/remove_from_global_cluster.html for full documentation.
docdb_remove_from_global_cluster(GlobalClusterIdentifier, DbClusterIdentifier)[required] The cluster identifier to detach from the Amazon DocumentDB global cluster.
[required] The Amazon Resource Name (ARN) identifying the cluster that was detached from the Amazon DocumentDB global cluster.