Removes a source identifier from an existing Amazon DocumentDB event notification subscription.
See https://paws-r.github.io/docs/docdb/remove_source_identifier_from_subscription.html for full documentation.
docdb_remove_source_identifier_from_subscription(
SubscriptionName,
SourceIdentifier
)[required] The name of the Amazon DocumentDB event notification subscription that you want to remove a source identifier from.
[required] The source identifier to be removed from the subscription, such as the instance identifier for an instance, or the name of a security group.