Learn R Programming

paws.database (version 0.2.0)

dynamodb_create_global_table: Creates a global table from an existing table

Description

Creates a global table from an existing table. A global table creates a replication relationship between two or more DynamoDB tables with the same table name in the provided Regions.

See https://paws-r.github.io/docs/dynamodb/create_global_table.html for full documentation.

Usage

dynamodb_create_global_table(GlobalTableName, ReplicationGroup)

Arguments

GlobalTableName

[required] The global table name.

ReplicationGroup

[required] The Regions where the global table needs to be created.