Returns information about contributor insights, for a given table or global secondary index.
See https://paws-r.github.io/docs/dynamodb/describe_contributor_insights.html for full documentation.
dynamodb_describe_contributor_insights(TableName, IndexName = NULL)[required] The name of the table to describe.
The name of the global secondary index to describe, if applicable.