Returns information about contributor insights, for a given table or global secondary index.
dynamodb_describe_contributor_insights(TableName, IndexName)[required] The name of the table to describe.
The name of the global secondary index to describe, if applicable.
A list with the following syntax:
list(
TableName = "string",
IndexName = "string",
ContributorInsightsRuleList = list(
"string"
),
ContributorInsightsStatus = "ENABLING"|"ENABLED"|"DISABLING"|"DISABLED"|"FAILED",
LastUpdateDateTime = as.POSIXct(
"2015-01-01"
),
FailureException = list(
ExceptionName = "string",
ExceptionDescription = "string"
)
)
svc$describe_contributor_insights( TableName = "string", IndexName = "string" )