Returns the current provisioned-capacity quotas for your Amazon Web Services account in a Region, both for the Region as a whole and for any one DynamoDB table that you create there.
See https://paws-r.github.io/docs/dynamodb/describe_limits.html for full documentation.
dynamodb_describe_limits()