List all tags on an Amazon DynamoDB resource. You can call ListTagsOfResource up to 10 times per second, per account.
dynamodb_list_tags_of_resource(ResourceArn, NextToken)[required] The Amazon DynamoDB resource with tags to be listed. This value is an Amazon Resource Name (ARN).
An optional string that, if supplied, must be copied from the output of a previous call to ListTagOfResource. When provided in this manner, this API fetches the next page of results.
svc$list_tags_of_resource( ResourceArn = "string", NextToken = "string" )
For an overview on tagging DynamoDB resources, see Tagging for DynamoDB in the Amazon DynamoDB Developer Guide.