Updates auto scaling settings on your global tables at once.
See https://paws-r.github.io/docs/dynamodb/update_table_replica_auto_scaling.html for full documentation.
dynamodb_update_table_replica_auto_scaling(
GlobalSecondaryIndexUpdates = NULL,
TableName,
ProvisionedWriteCapacityAutoScalingUpdate = NULL,
ReplicaUpdates = NULL
)Represents the auto scaling settings of the global secondary indexes of the replica to be updated.
[required] The name of the global table to be updated.
Represents the auto scaling settings of replicas of the table that will be modified.