View source: R/elasticache_operations.R
| elasticache_create_user_group | R Documentation |
For Valkey engine version 7.2 onwards and Redis OSS 6.0 to 7.1: Creates a user group. For more information, see Using Role Based Access Control (RBAC)
See https://www.paws-r-sdk.com/docs/elasticache_create_user_group/ for full documentation.
elasticache_create_user_group(UserGroupId, Engine, UserIds = NULL, Tags = NULL)
UserGroupId |
[required] The ID of the user group. This value is stored as a lowercase string. |
Engine |
[required] Sets the engine listed in a user group. The options are valkey or redis. |
UserIds |
The list of user IDs that belong to the user group. |
Tags |
A list of tags to be added to this resource. A tag is a key-value pair. A tag key must be accompanied by a tag value, although null is accepted. Available for Valkey and Redis OSS only. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.