Used to failover the primary region to a selected secondary region. The selected secondary region will become primary, and all other clusters will become secondary.
See https://paws-r.github.io/docs/elasticache/failover_global_replication_group.html for full documentation.
elasticache_failover_global_replication_group(
GlobalReplicationGroupId,
PrimaryRegion,
PrimaryReplicationGroupId
)[required] The name of the Global datastore
[required] The Amazon region of the primary cluster of the Global datastore
[required] The name of the primary replication group