Learn R Programming

paws.database (version 0.2.0)

elasticache_modify_user_group: Changes the list of users that belong to the user group

Description

Changes the list of users that belong to the user group.

See https://paws-r.github.io/docs/elasticache/modify_user_group.html for full documentation.

Usage

elasticache_modify_user_group(
  UserGroupId,
  UserIdsToAdd = NULL,
  UserIdsToRemove = NULL
)

Arguments

UserGroupId

[required] The ID of the user group.

UserIdsToAdd

The list of user IDs to add to the user group.

UserIdsToRemove

The list of user IDs to remove from the user group.