Learn R Programming

paws.database (version 0.1.6)

elasticache_remove_tags_from_resource: Removes the tags identified by the TagKeys list from the named resource

Description

Removes the tags identified by the TagKeys list from the named resource.

Usage

elasticache_remove_tags_from_resource(ResourceName, TagKeys)

Arguments

ResourceName

[required] The Amazon Resource Name (ARN) of the resource from which you want the tags removed, for example arn:aws:elasticache:us-west-2:0123456789:cluster:myCluster or arn:aws:elasticache:us-west-2:0123456789:snapshot:mySnapshot.

For more information about ARNs, see Amazon Resource Names (ARNs) and AWS Service Namespaces.

TagKeys

[required] A list of TagKeys identifying the tags you want removed from the named resource.

Request syntax

svc$remove_tags_from_resource(
  ResourceName = "string",
  TagKeys = list(
    "string"
  )
)