Start the migration of data.
See https://paws-r.github.io/docs/elasticache/start_migration.html for full documentation.
elasticache_start_migration(ReplicationGroupId, CustomerNodeEndpointList)[required] The ID of the replication group to which data should be migrated.
[required] List of endpoints from which data should be migrated. For Redis (cluster mode disabled), list should have only one element.