View source: R/keyspaces_operations.R
| keyspaces_delete_type | R Documentation |
The delete_type operation deletes a user-defined type (UDT). You can only delete a type that is not used in a table or another UDT.
See https://www.paws-r-sdk.com/docs/keyspaces_delete_type/ for full documentation.
keyspaces_delete_type(keyspaceName, typeName)
keyspaceName |
[required] The name of the keyspace of the to be deleted type. |
typeName |
[required] The name of the type to be deleted. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.