Learn R Programming

paws.database (version 0.2.0)

keyspaces_get_keyspace: Returns the name and the Amazon Resource Name (ARN) of the specified table

Description

Returns the name and the Amazon Resource Name (ARN) of the specified table.

See https://paws-r.github.io/docs/keyspaces/get_keyspace.html for full documentation.

Usage

keyspaces_get_keyspace(keyspaceName)

Arguments

keyspaceName

[required] The name of the keyspace.