View source: R/keyspaces_operations.R
| keyspaces_list_types | R Documentation |
The list_types operation returns a list of types for a specified keyspace.
See https://www.paws-r-sdk.com/docs/keyspaces_list_types/ for full documentation.
keyspaces_list_types(nextToken = NULL, maxResults = NULL, keyspaceName)
nextToken |
The pagination token. To resume pagination, provide the |
maxResults |
The total number of types to return in the output. If the total number of types available is more than the value specified, a |
keyspaceName |
[required] The name of the keyspace that contains the listed types. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.