Restores the specified table to the specified point in time within the earliest_restorable_timestamp and the current time. For more information about restore points, see Time window for PITR continuous backups in the Amazon Keyspaces Developer Guide.
See https://paws-r.github.io/docs/keyspaces/restore_table.html for full documentation.
keyspaces_restore_table(
sourceKeyspaceName,
sourceTableName,
targetKeyspaceName,
targetTableName,
restoreTimestamp = NULL,
capacitySpecificationOverride = NULL,
encryptionSpecificationOverride = NULL,
pointInTimeRecoveryOverride = NULL,
tagsOverride = NULL
)[required] The keyspace name of the source table.
[required] The name of the source table.
[required] The name of the target keyspace.
[required] The name of the target table.
The restore timestamp in ISO 8601 format.
Specifies the read/write throughput capacity mode for the target table. The options are:
• throughputMode:PAY_PER_REQUEST
• throughputMode:PROVISIONED - Provisioned capacity mode requires
readCapacityUnits and writeCapacityUnits as input.
The default is throughput_mode:PAY_PER_REQUEST.
For more information, see Read/write capacity modes in the Amazon Keyspaces Developer Guide.
Specifies the encryption settings for the target table. You can choose one of the following KMS key (KMS key):
• type:AWS_OWNED_KMS_KEY - This key is owned by Amazon Keyspaces.
• type:CUSTOMER_MANAGED_KMS_KEY - This key is stored in your account
and is created, owned, and managed by you. This option requires the
kms_key_identifier of the KMS key in Amazon Resource Name (ARN) format
as input.
The default is type:AWS_OWNED_KMS_KEY.
For more information, see Encryption at rest in the Amazon Keyspaces Developer Guide.
Specifies the pointInTimeRecovery settings for the target table. The
options are:
• ENABLED
• DISABLED
If it's not specified, the default is DISABLED.
For more information, see Point-in-time recovery in the Amazon Keyspaces Developer Guide.
A list of key-value pair tags to be attached to the restored table.
For more information, see Adding tags and labels to Amazon Keyspaces resources in the Amazon Keyspaces Developer Guide.