View source: R/keyspaces_operations.R
| keyspaces_update_keyspace | R Documentation |
Adds a new Amazon Web Services Region to the keyspace. You can add a new Region to a keyspace that is either a single or a multi-Region keyspace. Amazon Keyspaces is going to replicate all tables in the keyspace to the new Region. To successfully replicate all tables to the new Region, they must use client-side timestamps for conflict resolution. To enable client-side timestamps, specify clientSideTimestamps.status = enabled when invoking the API. For more information about client-side timestamps, see Client-side timestamps in Amazon Keyspaces in the Amazon Keyspaces Developer Guide.
See https://www.paws-r-sdk.com/docs/keyspaces_update_keyspace/ for full documentation.
keyspaces_update_keyspace(
keyspaceName,
replicationSpecification,
clientSideTimestamps = NULL
)
keyspaceName |
[required] The name of the keyspace. |
replicationSpecification |
[required] The replication specification of the keyspace includes:
|
clientSideTimestamps |
The client-side timestamp setting of the table. For more information, see How it works: Amazon Keyspaces client-side timestamps in the Amazon Keyspaces Developer Guide. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.