View source: R/lakeformation_operations.R
| lakeformation_create_lake_formation_opt_in | R Documentation |
Enforce Lake Formation permissions for the given databases, tables, and principals.
See https://www.paws-r-sdk.com/docs/lakeformation_create_lake_formation_opt_in/ for full documentation.
lakeformation_create_lake_formation_opt_in(
Principal,
Resource,
Condition = NULL
)
Principal |
[required] The Lake Formation principal. Supported principals are IAM users or IAM roles. |
Resource |
[required] A structure for the resource. |
Condition |
A Lake Formation condition, which applies to permissions and opt-ins that contain an expression. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.