Learn R Programming

paws.database (version 0.2.0)

lakeformation_deregister_resource: Deregisters the resource as managed by the Data Catalog

Description

Deregisters the resource as managed by the Data Catalog.

See https://paws-r.github.io/docs/lakeformation/deregister_resource.html for full documentation.

Usage

lakeformation_deregister_resource(ResourceArn)

Arguments

ResourceArn

[required] The Amazon Resource Name (ARN) of the resource that you want to deregister.