View source: R/lakeformation_operations.R
| lakeformation_get_temporary_data_location_credentials | R Documentation |
Allows a user or application in a secure environment to access data in a specific Amazon S3 location registered with Lake Formation by providing temporary scoped credentials that are limited to the requested data location and the caller's authorized access level.
See https://www.paws-r-sdk.com/docs/lakeformation_get_temporary_data_location_credentials/ for full documentation.
lakeformation_get_temporary_data_location_credentials(
DurationSeconds = NULL,
AuditContext = NULL,
DataLocations = NULL,
CredentialsScope = NULL
)
DurationSeconds |
The time period, between 900 and 43,200 seconds, for the timeout of the temporary credentials. |
AuditContext |
A structure used to include auditing information on the privileged API. |
DataLocations |
The Amazon S3 data location that you want to access. |
CredentialsScope |
The credential scope is determined by the caller's Lake Formation permission on the associated table. Credential scope can be either:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.