Registers the resource as managed by the Data Catalog.
See https://paws-r.github.io/docs/lakeformation/register_resource.html for full documentation.
lakeformation_register_resource(
ResourceArn,
UseServiceLinkedRole = NULL,
RoleArn = NULL
)[required] The Amazon Resource Name (ARN) of the resource that you want to register.
Designates an Identity and Access Management (IAM) service-linked role by registering this role with the Data Catalog. A service-linked role is a unique type of IAM role that is linked directly to Lake Formation.
For more information, see Using Service-Linked Roles for Lake Formation.
The identifier for the role that registers the resource.