Learn R Programming

paws.database (version 0.2.0)

lakeformation_update_resource: Updates the data access role used for vending access to the given (registered) resource in Lake Formation

Description

Updates the data access role used for vending access to the given (registered) resource in Lake Formation.

See https://paws-r.github.io/docs/lakeformation/update_resource.html for full documentation.

Usage

lakeformation_update_resource(RoleArn, ResourceArn)

Arguments

RoleArn

[required] The new role to use for the given resource registered in Lake Formation.

ResourceArn

[required] The resource ARN.