Updates the data access role used for vending access to the given (registered) resource in Lake Formation.
See https://paws-r.github.io/docs/lakeformation/update_resource.html for full documentation.
lakeformation_update_resource(RoleArn, ResourceArn)[required] The new role to use for the given resource registered in Lake Formation.
[required] The resource ARN.