Apply the service update to a list of clusters supplied. For more information on service updates and applying them, see Applying the service updates.
See https://paws-r.github.io/docs/memorydb/batch_update_cluster.html for full documentation.
memorydb_batch_update_cluster(ClusterNames, ServiceUpdate = NULL)[required] The cluster names to apply the updates.
The unique ID of the service update