Deletes a cluster. It also deletes all associated nodes and node endpoints
See https://paws-r.github.io/docs/memorydb/delete_cluster.html for full documentation.
memorydb_delete_cluster(ClusterName, FinalSnapshotName = NULL)[required] The name of the cluster to be deleted
The user-supplied name of a final cluster snapshot. This is the unique name that identifies the snapshot. MemoryDB creates the snapshot, and then deletes the cluster immediately afterward.