Deletes the specified parameter group. You cannot delete a parameter group if it is associated with any clusters. You cannot delete the default parameter groups in your account.
See https://paws-r.github.io/docs/memorydb/delete_parameter_group.html for full documentation.
memorydb_delete_parameter_group(ParameterGroupName)[required] The name of the parameter group to delete.