View source: R/memorydb_operations.R
| memorydb_update_multi_region_cluster | R Documentation |
Updates the configuration of an existing multi-Region cluster.
See https://www.paws-r-sdk.com/docs/memorydb_update_multi_region_cluster/ for full documentation.
memorydb_update_multi_region_cluster(
MultiRegionClusterName,
NodeType = NULL,
Description = NULL,
EngineVersion = NULL,
ShardConfiguration = NULL,
MultiRegionParameterGroupName = NULL,
UpdateStrategy = NULL
)
MultiRegionClusterName |
[required] The name of the multi-Region cluster to be updated. |
NodeType |
The new node type to be used for the multi-Region cluster. |
Description |
A new description for the multi-Region cluster. |
EngineVersion |
The new engine version to be used for the multi-Region cluster. |
ShardConfiguration |
Shard configuration options. Each shard configuration has the following: Slots and ReplicaCount. |
MultiRegionParameterGroupName |
The new multi-Region parameter group to be associated with the cluster. |
UpdateStrategy |
The strategy to use for the update operation. Supported values are "coordinated" or "uncoordinated". |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.