Displays a list of categories for all event source types, or, if specified, for a specified source type.
See https://paws-r.github.io/docs/neptune/describe_event_categories.html for full documentation.
neptune_describe_event_categories(SourceType = NULL, Filters = NULL)The type of source that is generating the events.
Valid values: db-instance | db-parameter-group | db-security-group | db-snapshot
This parameter is not currently supported.