Detaches a Neptune DB cluster from a Neptune global database. A secondary cluster becomes a normal standalone cluster with read-write capability instead of being read-only, and no longer receives data from a the primary cluster.
See https://paws-r.github.io/docs/neptune/remove_from_global_cluster.html for full documentation.
neptune_remove_from_global_cluster(
GlobalClusterIdentifier,
DbClusterIdentifier
)[required] The identifier of the Neptune global database from which to detach the specified Neptune DB cluster.
[required] The Amazon Resource Name (ARN) identifying the cluster to be detached from the Neptune global database cluster.