Removes a source identifier from an existing event notification subscription.
See https://paws-r.github.io/docs/neptune/remove_source_identifier_from_subscription.html for full documentation.
neptune_remove_source_identifier_from_subscription(
SubscriptionName,
SourceIdentifier
)[required] The name of the event notification subscription you want to remove a source identifier from.
[required] The source identifier to be removed from the subscription, such as the DB instance identifier for a DB instance or the name of a security group.