Cancels an export task in progress that is exporting a snapshot to Amazon S3. Any data that has already been written to the S3 bucket isn't removed.
See https://paws-r.github.io/docs/rds/cancel_export_task.html for full documentation.
rds_cancel_export_task(ExportTaskIdentifier)[required] The identifier of the snapshot export task to cancel.