View source: R/rds_operations.R
| rds_describe_db_major_engine_versions | R Documentation |
Describes the properties of specific major versions of DB engines.
See https://www.paws-r-sdk.com/docs/rds_describe_db_major_engine_versions/ for full documentation.
rds_describe_db_major_engine_versions(
Engine = NULL,
MajorEngineVersion = NULL,
Marker = NULL,
MaxRecords = NULL
)
Engine |
The database engine to return major version details for. Valid Values:
|
MajorEngineVersion |
A specific database major engine version to return details for. Example: |
Marker |
An optional pagination token provided by a previous request. If this parameter is specified, the response includes only records beyond the marker, up to the value specified by |
MaxRecords |
The maximum number of records to include in the response. If more than the Default: 100 |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.