Detaches an Aurora secondary cluster from an Aurora global database cluster. The cluster becomes a standalone cluster with read-write capability instead of being read-only and receiving data from a primary cluster in a different Region.
See https://paws-r.github.io/docs/rds/remove_from_global_cluster.html for full documentation.
rds_remove_from_global_cluster(
GlobalClusterIdentifier = NULL,
DbClusterIdentifier = NULL
)The cluster identifier to detach from the Aurora global database cluster.
The Amazon Resource Name (ARN) identifying the cluster that was detached from the Aurora global database cluster.