Learn R Programming

paws.database (version 0.2.0)

rds_start_db_instance: Starts an Amazon RDS DB instance that was stopped using the Amazon Web Services console, the stop-db-instance CLI command, or the StopDBInstance action

Description

Starts an Amazon RDS DB instance that was stopped using the Amazon Web Services console, the stop-db-instance CLI command, or the StopDBInstance action.

See https://paws-r.github.io/docs/rds/start_db_instance.html for full documentation.

Usage

rds_start_db_instance(DBInstanceIdentifier)

Arguments

DBInstanceIdentifier

[required] The user-supplied instance identifier.