From a data producer account, authorizes the sharing of a datashare with one or more consumer accounts or managing entities. To authorize a datashare for a data consumer, the producer account must have the correct access permissions.
See https://paws-r.github.io/docs/redshift/authorize_data_share.html for full documentation.
redshift_authorize_data_share(DataShareArn, ConsumerIdentifier)[required] The Amazon Resource Name (ARN) of the datashare that producers are to authorize sharing for.
[required] The identifier of the data consumer that is authorized to access the datashare. This identifier is an Amazon Web Services account ID or a keyword, such as ADX.