Adds one or more tags to a specified resource.
redshift_create_tags(ResourceName, Tags)[required] The Amazon Resource Name (ARN) to which you want to add the tag or tags.
For example, arn:aws:redshift:us-east-1:123456789:cluster:t1.
[required] One or more name/value pairs to add as tags to the specified resource.
Each tag name is passed in with the parameter Key and the
corresponding value is passed in with the parameter Value. The Key
and Value parameters are separated by a comma (,). Separate multiple
tags with a space. For example,
--tags "Key"="owner","Value"="admin" "Key"="environment","Value"="test" "Key"="version","Value"="1.0".
svc$create_tags(
ResourceName = "string",
Tags = list(
list(
Key = "string",
Value = "string"
)
)
)
A resource can have up to 50 tags. If you try to create more than 50 tags for a resource, you will receive an error and the attempt will fail.
If you specify a key that already exists for the resource, the value for that key will be updated with the new value.