Deletes a partner integration from a cluster. Data can still flow to the cluster until the integration is deleted at the partner's website.
See https://paws-r.github.io/docs/redshift/delete_partner.html for full documentation.
redshift_delete_partner(
AccountId,
ClusterIdentifier,
DatabaseName,
PartnerName
)[required] The Amazon Web Services account ID that owns the cluster.
[required] The cluster identifier of the cluster that receives data from the partner.
[required] The name of the database that receives data from the partner.
[required] The name of the partner that is authorized to send data.