View source: R/redshift_operations.R
| redshift_deregister_namespace | R Documentation |
Deregisters a cluster or serverless namespace from the Amazon Web Services Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/redshift_deregister_namespace/ for full documentation.
redshift_deregister_namespace(NamespaceIdentifier, ConsumerIdentifiers)
NamespaceIdentifier |
[required] The unique identifier of the cluster or serverless namespace that you want to deregister. |
ConsumerIdentifiers |
[required] An array containing the ID of the consumer account that you want to deregister the cluster or serverless namespace from. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.