View source: R/redshift_operations.R
| redshift_get_identity_center_auth_token | R Documentation |
Generates an encrypted authentication token that propagates the caller's Amazon Web Services IAM Identity Center identity to Amazon Redshift clusters. This API extracts the Amazon Web Services IAM Identity Center identity from enhanced credentials and creates a secure token that Amazon Redshift drivers can use for authentication.
See https://www.paws-r-sdk.com/docs/redshift_get_identity_center_auth_token/ for full documentation.
redshift_get_identity_center_auth_token(ClusterIds)
ClusterIds |
[required] A list of cluster identifiers that the generated token can be used with. The token will be scoped to only allow authentication to the specified clusters. Constraints:
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.