Modifies whether a cluster can use AQUA (Advanced Query Accelerator).
See https://paws-r.github.io/docs/redshift/modify_aqua_configuration.html for full documentation.
redshift_modify_aqua_configuration(
ClusterIdentifier,
AquaConfigurationStatus = NULL
)[required] The identifier of the cluster to be modified.
The new value of AQUA configuration status. Possible values include the following.
enabled - Use AQUA if it is available for the current Amazon Web Services Region and Amazon Redshift node type.
disabled - Don't use AQUA.
auto - Amazon Redshift determines whether to use AQUA.