Modifies the database revision of a cluster. The database revision is a unique revision of the database running in a cluster.
See https://paws-r.github.io/docs/redshift/modify_cluster_db_revision.html for full documentation.
redshift_modify_cluster_db_revision(ClusterIdentifier, RevisionTarget)[required] The unique identifier of a cluster whose database revision you want to modify.
Example: examplecluster
[required] The identifier of the database revision. You can retrieve this value
from the response to the
describe_cluster_db_revisions
request.