Modifies a snapshot schedule for a cluster.
See https://paws-r.github.io/docs/redshift/modify_cluster_snapshot_schedule.html for full documentation.
redshift_modify_cluster_snapshot_schedule(
ClusterIdentifier,
ScheduleIdentifier = NULL,
DisassociateSchedule = NULL
)[required] A unique identifier for the cluster whose snapshot schedule you want to modify.
A unique alphanumeric identifier for the schedule that you want to associate with the cluster.
A boolean to indicate whether to remove the assoiciation between the cluster and the schedule.