View source: R/redshift_operations.R
| redshift_register_namespace | R Documentation |
Registers a cluster or serverless namespace to the Amazon Web Services Glue Data Catalog.
See https://www.paws-r-sdk.com/docs/redshift_register_namespace/ for full documentation.
redshift_register_namespace(NamespaceIdentifier, ConsumerIdentifiers)
NamespaceIdentifier |
[required] The unique identifier of the cluster or serverless namespace that you want to register. |
ConsumerIdentifiers |
[required] An array containing the ID of the consumer account that you want to register the namespace to. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.