Rotates the encryption keys for a cluster.
See https://paws-r.github.io/docs/redshift/rotate_encryption_key.html for full documentation.
redshift_rotate_encryption_key(ClusterIdentifier)[required] The unique identifier of the cluster that you want to rotate the encryption keys for.
Constraints: Must be the name of valid cluster that has encryption enabled.