Runs one or more SQL statements, which can be data manipulation language (DML) or data definition language (DDL). Depending on the authorization method, use one of the following combinations of request parameters:
See https://paws-r.github.io/docs/redshiftdataapiservice/batch_execute_statement.html for full documentation.
redshiftdataapiservice_batch_execute_statement(
ClusterIdentifier = NULL,
Database,
DbUser = NULL,
SecretArn = NULL,
Sqls,
StatementName = NULL,
WithEvent = NULL,
WorkgroupName = NULL
)The cluster identifier. This parameter is required when connecting to a cluster and authenticating using either Secrets Manager or temporary credentials.
[required] The name of the database. This parameter is required when authenticating using either Secrets Manager or temporary credentials.
The database user name. This parameter is required when connecting to a cluster and authenticating using temporary credentials.
The name or ARN of the secret that enables access to the database. This parameter is required when authenticating using Secrets Manager.
[required] One or more SQL statements to run.
The name of the SQL statements. You can name the SQL statements when you create them to identify the query.
A value that indicates whether to send an event to the Amazon EventBridge event bus after the SQL statements run.
The serverless workgroup name. This parameter is required when connecting to a serverless workgroup and authenticating using either Secrets Manager or temporary credentials.