View source: R/redshiftserverless_operations.R
| redshiftserverless_create_reservation | R Documentation |
Creates an Amazon Redshift Serverless reservation, which gives you the option to commit to a specified number of Redshift Processing Units (RPUs) for a year at a discount from Serverless on-demand (OD) rates.
See https://www.paws-r-sdk.com/docs/redshiftserverless_create_reservation/ for full documentation.
redshiftserverless_create_reservation(capacity, clientToken = NULL, offeringId)
capacity |
[required] The number of Redshift Processing Units (RPUs) to reserve. |
clientToken |
A unique, case-sensitive identifier that you provide to ensure the idempotency of the request. If not provided, the Amazon Web Services SDK populates this field. This token must be a valid UUIDv4 value. For more information about idempotency, see Making retries safe with idempotent APIs . |
offeringId |
[required] The ID of the offering associated with the reservation. The offering determines the payment schedule for the reservation. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.