Creates a snapshot of all databases in a namespace. For more information about snapshots, see Working with snapshots and recovery points.
See https://paws-r.github.io/docs/redshiftserverless/create_snapshot.html for full documentation.
redshiftserverless_create_snapshot(
namespaceName,
retentionPeriod = NULL,
snapshotName
)[required] The namespace to create a snapshot for.
How long to retain the created snapshot.
[required] The name of the snapshot.