Creates an workgroup in Amazon Redshift Serverless.
See https://paws-r.github.io/docs/redshiftserverless/create_workgroup.html for full documentation.
redshiftserverless_create_workgroup(
baseCapacity = NULL,
configParameters = NULL,
enhancedVpcRouting = NULL,
namespaceName,
publiclyAccessible = NULL,
securityGroupIds = NULL,
subnetIds = NULL,
tags = NULL,
workgroupName
)The base data warehouse capacity of the workgroup in Redshift Processing Units (RPUs).
An array of parameters to set for more control over a serverless
database. The options are datestyle, enable_user_activity_logging,
query_group, search_path, and max_query_execution_time.
The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC instead of over the internet.
[required] The name of the namespace to associate with the workgroup.
A value that specifies whether the workgroup can be accessed from a public network.
An array of security group IDs to associate with the workgroup.
An array of VPC subnet IDs to associate with the workgroup.
A array of tag instances.
[required] The name of the created workgroup.