Returns an array of recovery points.
See https://paws-r.github.io/docs/redshiftserverless/list_recovery_points.html for full documentation.
redshiftserverless_list_recovery_points(
endTime = NULL,
maxResults = NULL,
namespaceName = NULL,
nextToken = NULL,
startTime = NULL
)The time when creation of the recovery point finished.
An optional parameter that specifies the maximum number of results to
return. You can use nextToken to get the next page of results.
The name of the namespace to list recovery points for.
If your initial
list_recovery_points
operation returns a nextToken, you can include the returned
nextToken in subsequent
list_recovery_points
operations, which returns results in the next page.
The time when the recovery point's creation was initiated.