View source: R/redshiftserverless_operations.R
| redshiftserverless_list_tracks | R Documentation |
List the Amazon Redshift Serverless versions.
See https://www.paws-r-sdk.com/docs/redshiftserverless_list_tracks/ for full documentation.
redshiftserverless_list_tracks(maxResults = NULL, nextToken = NULL)
maxResults |
The maximum number of response records to return in each call. If the number of remaining response records exceeds the specified MaxRecords value, a value is returned in a marker field of the response. You can retrieve the next set of records by retrying the command with the returned marker value. |
nextToken |
If your initial |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.