Restores a namespace from a snapshot.
See https://paws-r.github.io/docs/redshiftserverless/restore_from_snapshot.html for full documentation.
redshiftserverless_restore_from_snapshot(
namespaceName,
ownerAccount = NULL,
snapshotArn = NULL,
snapshotName = NULL,
workgroupName
)[required] The name of the namespace to restore the snapshot to.
The Amazon Web Services account that owns the snapshot.
The Amazon Resource Name (ARN) of the snapshot to restore from.
The name of the snapshot to restore from.
[required] The name of the workgroup used to restore the snapshot.