View source: R/redshiftserverless_operations.R
| redshiftserverless_update_lakehouse_configuration | R Documentation |
Modifies the lakehouse configuration for a namespace. This operation allows you to manage Amazon Redshift federated permissions and Amazon Web Services IAM Identity Center trusted identity propagation.
See https://www.paws-r-sdk.com/docs/redshiftserverless_update_lakehouse_configuration/ for full documentation.
redshiftserverless_update_lakehouse_configuration(
catalogName = NULL,
dryRun = NULL,
lakehouseIdcApplicationArn = NULL,
lakehouseIdcRegistration = NULL,
lakehouseRegistration = NULL,
namespaceName
)
catalogName |
The name of the Glue Data Catalog that will be associated with the namespace enabled with Amazon Redshift federated permissions. Pattern: |
dryRun |
A boolean value that, if |
lakehouseIdcApplicationArn |
The Amazon Resource Name (ARN) of the IAM Identity Center application used for enabling Amazon Web Services IAM Identity Center trusted identity propagation on a namespace enabled with Amazon Redshift federated permissions. |
lakehouseIdcRegistration |
Modifies the Amazon Web Services IAM Identity Center trusted identity propagation on a namespace enabled with Amazon Redshift federated permissions. Valid values are |
lakehouseRegistration |
Specifies whether to register or deregister the namespace with Amazon Redshift federated permissions. Valid values are |
namespaceName |
[required] The name of the namespace whose lakehouse configuration you want to modify. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.