Updates a namespace with the specified settings.
See https://paws-r.github.io/docs/redshiftserverless/update_namespace.html for full documentation.
redshiftserverless_update_namespace(
adminUserPassword = NULL,
adminUsername = NULL,
defaultIamRoleArn = NULL,
iamRoles = NULL,
kmsKeyId = NULL,
logExports = NULL,
namespaceName
)The password of the administrator for the first database created in the namespace.
The username of the administrator for the first database created in the namespace.
The Amazon Resource Name (ARN) of the IAM role to set as a default in the namespace.
A list of IAM roles to associate with the namespace.
The ID of the Amazon Web Services Key Management Service key used to encrypt your data.
The types of logs the namespace can export. The export types are
userlog, connectionlog, and useractivitylog.
[required] The name of the namespace.