Updates a workgroup with the specified configuration settings.
See https://paws-r.github.io/docs/redshiftserverless/update_workgroup.html for full documentation.
redshiftserverless_update_workgroup(
baseCapacity = NULL,
configParameters = NULL,
enhancedVpcRouting = NULL,
publiclyAccessible = NULL,
securityGroupIds = NULL,
subnetIds = NULL,
workgroupName
)The new base data warehouse capacity in Redshift Processing Units (RPUs).
An array of parameters to set for advanced control over a database. The
options are datestyle, enable_user_activity_logging, query_group,
search_path, and max_query_execution_time.
The value that specifies whether to turn on enhanced virtual private cloud (VPC) routing, which forces Amazon Redshift Serverless to route traffic through your VPC.
A value that specifies whether the workgroup can be accessible from a public network.
An array of security group IDs to associate with the workgroup.
An array of VPC subnet IDs to associate with the workgroup.
[required] The name of the workgroup to update.