The batch_put_attributes operation creates or replaces attributes within one or more items. By using this operation, the client can perform multiple PutAttribute operation with a single call. This helps yield savings in round trips and latencies, enabling Amazon SimpleDB to optimize requests and generally produce better throughput.
See https://paws-r.github.io/docs/simpledb/batch_put_attributes.html for full documentation.
simpledb_batch_put_attributes(DomainName, Items)[required] The name of the domain in which the attributes are being stored.
[required] A list of items on which to perform the operation.