Creates a new Timestream database. If the KMS key is not specified, the database will be encrypted with a Timestream managed KMS key located in your account. Refer to Amazon Web Services managed KMS keys for more info. Service quotas apply. See code sample for details.
See https://paws-r.github.io/docs/timestreamwrite/create_database.html for full documentation.
timestreamwrite_create_database(DatabaseName, KmsKeyId = NULL, Tags = NULL)[required] The name of the Timestream database.
The KMS key for the database. If the KMS key is not specified, the database will be encrypted with a Timestream managed KMS key located in your account. Refer to Amazon Web Services managed KMS keys for more info.
A list of key-value pairs to label the table.