Deletes a given Timestream table. This is an irreversible operation. After a Timestream database table is deleted, the time series data stored in the table cannot be recovered.
See https://paws-r.github.io/docs/timestreamwrite/delete_table.html for full documentation.
timestreamwrite_delete_table(DatabaseName, TableName)[required] The name of the database where the Timestream database is to be deleted.
[required] The name of the Timestream table to be deleted.